@@ -1,5 +1,5 @@
 --
---  $Id: od-a-api.sql,v 1.3.2.2 2011/08/01 14:05:25 source Exp $
+--  $Id: od-a-api.sql,v 1.1.2.4 2009/12/07 12:33:45 source Exp $
 --
 --  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 --  project.
@@ -122,55 +122,6 @@ create procedure ODS.ODS_API.inheritance2string (
 }
 ;
 
--------------------------------------------------------------------------------
---
-create procedure ODS.ODS_API."briefcase.list" (
-  in path varchar) __soap_http 'text/xml'
-{
-  declare uname, upassword, instance_iri varchar;
-  declare inst_id, id integer;
-  declare N integer;
-  declare sql, params, state, msg, meta, items any;
-
-  path := ODRIVE.WA.path_normalize (path, 'C');
-
-  inst_id := ODS.ODS_API.briefcase_instance (path);
-  if (not ods_check_auth (uname, inst_id))
-    return ods_auth_failed ();
-
-  instance_iri := SIOC..briefcase_iri (ODRIVE.WA.domain_name (inst_id));
-  upassword := ODRIVE.WA.account_password (ODRIVE.WA.account_id (uname));
-
-  sql := 'select TOP 100 rs.* from ODRIVE.WA.odrive_proc (rs0, rs1, rs2, rs3, rs4, rs5)(c0 varchar, c1 varchar, c2 integer, c3 varchar, c4 varchar, c5 varchar, c6 varchar, c7 varchar, c8 varchar, c9 varchar) rs where rs0 = ? and rs1 = ? and rs2 = ? and rs3 = ? and rs4 = ? and rs5 = ? order by c9, c3, c1';
-  params := vector (path, 0, null, null, uname, upassword);
-
-  set_user_id('dba');
-  state := '00000';
-  exec (sql, state, msg, params, 0, meta, items);
-  if (state <> '00000')
-    signal (state, msg);
-
-  http ('<?xml version="1.0"?>\n');
-  http ('<items>\n');
-  foreach (any item in items) do
-  {
-    http (sprintf ('<item path="%V">\n', ODRIVE.WA.utf2wide(item[8])));
-      http (sprintf ('<uri>%V</uri>\n', SIOC..post_iri_ex (instance_iri, DB.DBA.DAV_SEARCH_ID (item[8], item[1]))));
-      http (sprintf ('<name>%V</name>\n', ODRIVE.WA.utf2wide (item[0])));
-      http (sprintf ('<mimeType>%V</mimeType>\n', item[4]));
-      http (sprintf ('<size>%V</size>\n', cast(item[2] as varchar)));
-      http (sprintf ('<owner>%V</owner>\n', item[5]));
-      http (sprintf ('<group>%V</group>\n', item[6]));
-      http (sprintf ('<permissions>%V</permissions>\n', item[7]));
-      http (sprintf ('<modification>%V</modification>\n', item[3]));
-    http ('</item>\n');
-  }
-  http ('</items>\n');
-
-  return '';
-}
-;
-
 -------------------------------------------------------------------------------
 --
 create procedure ODS.ODS_API."briefcase.info" (
@@ -235,6 +186,15 @@ create procedure ODS.ODS_API."briefcase.resource.info" (
 }
 ;
 
+-------------------------------------------------------------------------------
+--
+create procedure ODS.ODS_API."briefcase.collection.info" (
+  in path varchar) __soap_http 'text/xml'
+{
+  return ODS.ODS_API."briefcase.info" (path, 'C');
+}
+;
+
 -------------------------------------------------------------------------------
 --
 create procedure ODS.ODS_API."briefcase.resource.vc.set" (
@@ -641,15 +601,6 @@ create procedure ODS.ODS_API."briefcase.resource.delete" (
 }
 ;
 
--------------------------------------------------------------------------------
---
-create procedure ODS.ODS_API."briefcase.collection.info" (
-  in path varchar) __soap_http 'text/xml'
-{
-  return ODS.ODS_API."briefcase.info" (path, 'C');
-}
-;
-
 -------------------------------------------------------------------------------
 --
 create procedure ODS.ODS_API."briefcase.collection.create" (
@@ -714,11 +665,10 @@ create procedure ODS.ODS_API."briefcase.copy" (
   in overwrite integer := 1,
   in permissions varchar := '110100000RR') __soap_http 'text/xml'
 {
-  declare uname, upassword, targetPath varchar;
+  declare uname, upassword varchar;
   declare rc integer;
   declare uid, gid integer;
   declare inst_id, inst_id2 integer;
-  declare from_item, to_item any;
 
   declare exit handler for sqlstate '*'
   {
@@ -736,20 +686,9 @@ create procedure ODS.ODS_API."briefcase.copy" (
     return ods_auth_failed ();
 
   whenever not found goto ret;
-  rc := -1;
   select U_ID, U_GROUP into uid, gid from DB.DBA.SYS_USERS where U_NAME = uname;
   upassword := ODRIVE.WA.account_password (ODRIVE.WA.account_id (uname));
-  from_item := ODRIVE.WA.DAV_INIT (from_path, uname, upassword);
-  if (ODRIVE.WA.dav_error (from_item))
-    return ods_serialize_int_res (from_item);
-  to_item := ODRIVE.WA.DAV_INIT (to_path, uname, upassword);
-  if (ODRIVE.WA.dav_error (to_item))
-    return ods_serialize_int_res (to_item);
-  targetPath := to_path || ODRIVE.WA.DAV_GET (from_item, 'name');
-  if (ODRIVE.WA.DAV_GET (from_item, 'type') = 'C')
-    targetPath := targetPath || '/';
-
-  rc := DB.DBA.DAV_COPY (from_path, targetPath, overwrite, permissions, uid, gid, uname, upassword);
+  rc := DB.DBA.DAV_COPY (from_path, to_path, overwrite, permissions, uid, gid, uname, upassword);
 ret:
   return ods_serialize_int_res (rc);
 }
@@ -762,10 +701,9 @@ create procedure ODS.ODS_API."briefcase.move" (
   in to_path varchar,
   in overwrite integer := 1) __soap_http 'text/xml'
 {
-  declare uname, upassword, targetPath varchar;
+  declare uname, upassword varchar;
   declare rc integer;
   declare inst_id, inst_id2 integer;
-  declare from_item, to_item any;
 
   declare exit handler for sqlstate '*'
   {
@@ -783,17 +721,7 @@ create procedure ODS.ODS_API."briefcase.move" (
     return ods_auth_failed ();
 
   upassword := ODRIVE.WA.account_password (ODRIVE.WA.account_id (uname));
-  from_item := ODRIVE.WA.DAV_INIT (from_path, uname, upassword);
-  if (ODRIVE.WA.dav_error (from_item))
-    return ods_serialize_int_res (from_item);
-  to_item := ODRIVE.WA.DAV_INIT (to_path, uname, upassword);
-  if (ODRIVE.WA.dav_error (to_item))
-    return ods_serialize_int_res (to_item);
-  targetPath := to_path || ODRIVE.WA.DAV_GET (from_item, 'name');
-  if (ODRIVE.WA.DAV_GET (from_item, 'type') = 'C')
-    targetPath := targetPath || '/';
-
-  rc := DB.DBA.DAV_MOVE (from_path, targetPath, overwrite, uname, upassword);
+  rc := DB.DBA.DAV_MOVE (from_path, to_path, overwrite, uname, upassword);
   return ods_serialize_int_res (rc);
 }
 ;
@@ -973,7 +901,7 @@ create procedure ODS.ODS_API."briefcase.share.add" (
     return ods_auth_failed ();
 
   user_id := ODRIVE.WA.account_id ("user");
-  if (user_id = -1)
+  if (isnull (user_id))
     signal ('22023', 'The user name does not exist');
 
   "allow" := ODS.ODS_API.permissions2array ("allow");
@@ -1039,7 +967,7 @@ create procedure ODS.ODS_API."briefcase.share.remove" (
     return ods_auth_failed ();
 
   user_id := ODRIVE.WA.account_id ("user");
-  if (user_id = -1)
+  if (isnull (user_id))
     signal ('22023', 'The user name does not exist');
 
   upassword := ODRIVE.WA.account_password (ODRIVE.WA.account_id (uname));
@@ -1149,7 +1077,7 @@ create procedure ODS.ODS_API."briefcase.options.set" (
   if (not exists (select 1 from DB.DBA.WA_INSTANCE where WAI_ID = inst_id and WAI_TYPE_NAME = 'oDrive'))
     return ods_serialize_sql_error ('37000', 'The instance is not found');
 
-	account_id := ODRIVE.WA.account_id (uname);
+	account_id := (select U_ID from WS.WS.SYS_DAV_USER where U_NAME = uname);
 	optionsParams := split_and_decode (options, 0, '%\0,='); -- XXX: FIXME
 
 	settings := ODRIVE.WA.settings (account_id);
@@ -1189,7 +1117,7 @@ create procedure ODS.ODS_API."briefcase.options.get" (
   if (not exists (select 1 from DB.DBA.WA_INSTANCE where WAI_ID = inst_id and WAI_TYPE_NAME = 'oDrive'))
     return ods_serialize_sql_error ('37000', 'The instance is not found');
 
-	account_id := ODRIVE.WA.account_id (uname);
+	account_id := (select U_ID from WS.WS.SYS_DAV_USER where U_NAME = uname);
 	settings := ODRIVE.WA.settings (account_id);
 	ODRIVE.WA.settings_init (settings);
 
@@ -1207,7 +1135,6 @@ create procedure ODS.ODS_API."briefcase.options.get" (
 
 grant select on WS.WS.SYS_DAV_RES to ODS_API;
 
-grant execute on ODS.ODS_API."briefcase.list" to ODS_API;
 grant execute on ODS.ODS_API."briefcase.resource.info" to ODS_API;
 grant execute on ODS.ODS_API."briefcase.resource.get" to ODS_API;
 grant execute on ODS.ODS_API."briefcase.resource.store" to ODS_API;
