@@ -1,5 +1,5 @@
 --
---  $Id: sioc_briefcase.sql,v 1.16.2.3 2010/01/28 00:30:12 source Exp $
+--  $Id: sioc_briefcase.sql,v 1.16.2.5 2010/07/06 23:08:51 source Exp $
 --
 --  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 --  project.
@@ -71,7 +71,7 @@ create procedure briefcase_sparql (
   declare st, msg, meta, rows any;
 
   st := '00000';
-  exec (sql, st, msg, vector (), 0, meta, rows);
+  exec (sql, st, msg, vector (), vector ('use_cache', 1), meta, rows);
   if ('00000' = st)
     return rows;
   return vector ();
@@ -801,7 +801,7 @@ create procedure waGroup (
   in id integer,
   in name varchar)
 {
-  return sprintf ('%s/%s#%s', waGraph (), ODRIVE.WA.account_name (id), name);
+  return sprintf ('%s/%s#%U', waGraph (), ODRIVE.WA.account_name (id), name);
 }
 ;
 
