@@ -1,5 +1,5 @@
 --
---  $Id: nws-a-table.sql,v 1.16.2.2 2009/12/30 12:18:07 source Exp $
+--  $Id: nws-a-table.sql,v 1.16.2.3 2010/06/09 13:45:58 source Exp $
 --
 --  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 --  project.
@@ -40,6 +40,9 @@ ENEWS.WA.exec_no_error('
     EF_UPDATE_PERIOD varchar default \'hourly\',
     EF_UPDATE_FREQ integer default 1,
     EF_STORE_DAYS integer default 30,
+    EF_PSH_SERVER varchar,
+    EF_PSH_ENABLED integer default 0,
+    EF_PSH_TOKEN varchar,
     EF_TAG varchar,
     EF_LAST_UPDATE datetime,
     EF_QUEUE_FLAG integer,
@@ -70,6 +73,19 @@ ENEWS.WA.exec_no_error (
   'alter table ENEWS.WA.FEED add EF_IMAGE_URI varchar', 'C', 'ENEWS.WA.FEED', 'EF_IMAGE_URI'
 );
 
+ENEWS.WA.exec_no_error (
+  'alter table ENEWS.WA.FEED add EF_PSH_SERVER varchar', 'C', 'ENEWS.WA.FEED', 'EF_PSH_SERVER'
+);
+
+ENEWS.WA.exec_no_error (
+  'alter table ENEWS.WA.FEED add EF_PSH_ENABLED integer default 0', 'C', 'ENEWS.WA.FEED', 'EF_PSH_ENABLED'
+);
+
+ENEWS.WA.exec_no_error (
+  'alter table ENEWS.WA.FEED add EF_PSH_TOKEN varchar', 'C', 'ENEWS.WA.FEED', 'EF_PSH_TOKEN'
+);
+
+
 ENEWS.WA.exec_no_error('
   create trigger FEED_INSERT AFTER INSERT ON ENEWS.WA.FEED referencing new as N {
     ENEWS.WA.channel_trigger (N.EF_ID, N.EF_UPDATE_PERIOD, N.EF_UPDATE_FREQ);
