@@ -1,5 +1,5 @@
 /*
- *  $Id: enews.js,v 1.21.2.5 2010/01/29 20:21:29 source Exp $
+ *  $Id: enews.js,v 1.21.2.8 2010/07/09 14:37:01 source Exp $
  *
  *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
  *  project.
@@ -106,8 +106,12 @@ Feeds.initState = function (state)
   if (!state)
     var state = new Object();
 
-  state.sid = Feeds.readField('sid');
-  state.realm = Feeds.readField('realm');
+  var v = Feeds.readField('sid');
+  if (v)
+    state.sid = v;
+  var v = Feeds.readField('realm');
+  if (v)
+    state.sid = v;
   if (!state.tab)
     state.tab = 'feeds';
 
@@ -535,67 +539,13 @@ Feeds.listFavourites = function ()
   OAT.AJAX.GET(S, '', x);
 }
 
-Feeds.updateClaim = function (claimNo)
-{
-  if (claimNo == 'xxx')
-  {
-    if (($v('c_iri_xxx') == '') || ($v('c_relation_xxx') == '') || ($v('c_value_xxx') == ''))
-    {
-      alert ('The IRI, relation and value fileld can not be empty|');
-    }
-    else
-    {
-      var tr = $('c_tr_xxx');
-      if (tr)
-      {
-        var seqNo = parseInt($v('c_seqNo'));
-
-        var tr_add = OAT.Dom.create('tr');
-        tr_add.id = 'c_tr_'+seqNo;
-
-        var S = tr.innerHTML;
-        S = S.replace(/xxx/g, ''+seqNo);
-        S = S.replace(/add_16/g, 'del_16');
-
-        var tr_parent = $('c_tr').parentNode;
-        tr_parent.insertBefore(tr_add, $('c_tr'));
-        tr_add.innerHTML = S;
-
-        var cl = new OAT.Combolist([], 'rdfs:seeAlso');
-        cl.input.name = 'c_relation_'+seqNo;
-        cl.input.id = 'c_relation_'+seqNo;
-        cl.input.style.width = "80%";
-        var td = $('c_td_'+seqNo);
-        td.innerHTML = '';
-        td.appendChild(cl.div);
-        cl.addOption('rdfs:seeAlso');
-        cl.addOption('foaf:made');
-        cl.addOption('foaf:maker');
-
-        $('c_iri_'+seqNo).value = $v('c_iri_xxx');
-        $('c_relation_'+seqNo).value = $v('c_relation_xxx');
-        $('c_value_'+seqNo).value = $v('c_value_xxx');
-
-        $('c_seqNo').value = seqNo + 1;
-        $('c_iri_xxx').value = '';
-        $('c_relation_xxx').value = '';
-        $('c_value_xxx').value = '';
-      }
-    }
-  }
-  else
-  {
-    OAT.Dom.unlink('c_tr_'+claimNo);
-  }
-}
-
 Feeds.aboutDialog = function ()
 {
   var aboutDiv = $('aboutDiv');
   if (aboutDiv) {OAT.Dom.unlink(aboutDiv);}
-  aboutDiv = OAT.Dom.create('div', {width:'450px', height:'150px'});
+  aboutDiv = OAT.Dom.create('div', {width:'430px', height:'150px'});
   aboutDiv.id = 'aboutDiv';
-  aboutDialog = new OAT.Dialog('About ODS FeedsManager', aboutDiv, {width:450, buttons: 0, resize:0, modal:1});
+  aboutDialog = new OAT.Dialog('About ODS FeedsManager', aboutDiv, {width:445, buttons: 0, resize:0, modal:1});
 	aboutDialog.cancel = aboutDialog.hide;
 
   var x = function (txt) {
@@ -612,6 +562,13 @@ Feeds.aboutDialog = function ()
   OAT.AJAX.POST("ajax.vsp", "a=about", x, {type:OAT.AJAX.TYPE_TEXT, onstart:function(){}, onerror:function(){}});
 }
 
+function myA(obj) {
+  if (obj.href) {
+    document.location = obj.href + '?' + urlParam('sid') + urlParam('realm');
+    return false;
+  }
+}
+
 function myPost(frm_name, fld_name, fld_value)
 {
   createHidden(frm_name, fld_name, fld_value);
@@ -1172,6 +1129,14 @@ function menuPopup(button, menuID)
   return false;
 }
 
+function urlParam(fldName)
+{
+  var O = document.forms[0].elements[fldName];
+  if (O && O.value != '')
+    return '&' + fldName + '=' + encodeURIComponent(O.value);
+  return '';
+}
+
 function urlParams(mask)
 {
   var S = '';
@@ -1485,176 +1450,3 @@ function addChecked (form, txt, selectionMsq)
     window.opener.document.F1.submit();
   window.close();
 }
-
-var TBL = new Object();
-
-TBL.createRow = function (prefix, No, optionObject)
-{
-  if (No != null)
-  {
-    OAT.Dom.unlink(prefix+'_tr_'+No);
-    var No = parseInt($(prefix+'_no').value);
-    for (var N = 0; N < No; N++)
-    {
-      if ($(prefix+'_tr_'+N))
-        return;
-    }
-    OAT.Dom.show (prefix+'_tr_no');
-  }
-  else
-  {
-    var tbl = $(prefix+'_tbl');
-    if (tbl)
-    {
-      options = {btn_1: {mode: 1}};
-      for (var p in optionObject) {options[p] = optionObject[p]; }
-
-      No = optionObject.No;
-      if (!No) {
-        if (!$(prefix+'_no')) {
-        	var fld = OAT.Dom.create("input");
-          fld.type = 'hidden';
-          fld.name = prefix+'_no';
-          fld.id = fld.name;
-          fld.value = '0';
-          tbl.appendChild(fld);
-        }
-        No = $v(prefix+'_no');
-      }
-      No = parseInt(No)
-
-      OAT.Dom.hide (prefix+'_tr_no');
-
-      var tr = OAT.Dom.create('tr');
-      tr.id = prefix+'_tr_' + No;
-      tbl.appendChild(tr);
-
-      // fields
-      for (var fld in options)
-      {
-        if (fld.indexOf('fld') == 0)
-        {
-          var fldOptions = options[fld];
-          var td = OAT.Dom.create('td');
-          td.id = prefix+'_td_'+ No+'_'+fld.replace(/fld_/, '');
-          tr.appendChild(td);
-          TBL.createCell (td, prefix, fld, No, fldOptions)
-        }
-      }
-
-      // actions
-      var td = OAT.Dom.create('td');
-      td.id = prefix+'_td_'+ No+'_btn';
-      td.style.whiteSpace = 'nowrap';
-      tr.appendChild(td);
-      for (var btn in options)
-      {
-        if (btn.indexOf('btn') == 0)
-        {
-          var btnOptions = options[btn];
-          TBL.createButton(td, prefix, btn, No, btnOptions)
-        }
-      }
-      $(prefix+'_no').value = No + 1;
-    }
-  }
-}
-
-TBL.createCell = function (td, prefix, fldName, No, fldOptions)
-{
-  fldName = prefix + '_' + fldName + '_' + No;
-  if (fldOptions.tdCssText)
-    td.style.cssText = fldOptions.tdCssText;
-  var fn = TBL["createCell"+fldOptions.mode];
-  if (fn)
-	  fn(td, prefix, fldName, No, fldOptions);
-}
-
-TBL.createCell0 = function (td, prefix, fldName, No, fldOptions)
-{
-  var fld = OAT.Dom.create('input');
-  fld.type = (fldOptions.type)? (fldOptions.type): 'text';
-  fld.id = fldName;
-  fld.name = fld.id;
-  if (fldOptions.value)
-  {
-    fld.value = fldOptions.value;
-    fld.defaultValue = fld.value;
-  }
-  if (fldOptions.className)
-    fld.className = fldOptions.className;
-  if (fldOptions.onblur)
-    fld.onblur = fldOptions.onblur;
-  fld.style.width = '95%';
-  if (fldOptions.cssText)
-    fld.style.cssText = fldOptions.cssText;
-
-  td.appendChild(fld);
-  return fld;
-}
-
-TBL.createCell1 = function (td, prefix, fldName, No, fldOptions)
-{
-  var fld = TBL.createCell0 (td, prefix, fldName, No, fldOptions)
-  td.appendChild(OAT.Dom.text(' '));
-  var img = OAT.Dom.image('image/select.gif');
-  img.className = "pointer";
-  img.onclick = function (){windowShow('users_select.vspx?dst=m&params='+fldName+':s1;',520)};
-
-  td.appendChild(img);
-  return fld;
-}
-
-TBL.createCell2 = function (td, prefix, fldName, No, fldOptions)
-{
-  var fld = new OAT.Combolist([], fldOptions.value, {name: fldName});
-  fld.input.name = fldName;
-  fld.input.id = fldName;
-  fld.input.style.width = "80%";
-  fld.addOption('rdfs:seeAlso');
-  fld.addOption('foaf:made');
-  fld.addOption('foaf:maker');
-
-  td.appendChild(fld.div);
-  return fld;
-}
-
-TBL.createButton = function (td, prefix, fldName, No, fldOptions)
-{
-  fldName = prefix + '_' + fldName + '_' + No;
-  if (fldOptions.tdCssText)
-    td.style.cssText = fldOptions.tdCssText;
-  var fn = TBL["createButton"+fldOptions.mode];
-  if (fn)
-  {
-	  var btn = fn(td, prefix, fldName, No, fldOptions);
-    if (btn)
-    { if (fldOptions.cssText)
-        btn.style.cssText = fldOptions.cssText;
-      if (fldOptions.className)
-        btn.className = fldOptions.className;
-    }
-  }
-}
-
-TBL.createButton1 = function (td, prefix, fldName, No, fldOptions)
-{
-  var fld = OAT.Dom.create("input");
-  fld.id = fldName;
-  fld.type = 'button';
-  fld.value = 'Remove';
-  fld.onclick = function(){TBL.createRow(prefix, No);};
-
-  td.appendChild(fld);
-  return fld;
-}
-
-TBL.createButton2 = function (td, prefix, fldName, No, fldOptions)
-{
-  var fld = OAT.Dom.image('image/del_16.png');
-  fld.onclick = function(){TBL.createRow(prefix, No);};
-  OAT.Dom.addClass(fld, 'pointer');
-
-  td.appendChild(fld);
-  return fld;
-}
