@@ -19,7 +19,7 @@
 //  
 //  
 //
-// $Id: OdbcConnection.cs,v 1.3.4.1 2011/10/13 17:08:30 source Exp $
+// $Id: OdbcConnection.cs,v 1.3 2008/12/15 10:10:45 source Exp $
 //
 
 using System;
@@ -606,8 +606,6 @@ namespace OpenLink.Data.Virtuoso
 		protected override void Dispose (bool disposing)
 		{
 		  Debug.WriteLineIf (CLI.FnTrace.Enabled, "OdbcConnection.Dispose ()");
-			try
-			{
 			if (disposing)
 			{
 				Close ();
@@ -621,17 +619,10 @@ namespace OpenLink.Data.Virtuoso
 				OnDisconnect ();
 			}
 
-#if WIN3#if WIN32_FINALIZERS
+#if WIN32_FINALIZERS
 			//statementList.Unreference ();
 			Unreference ();
 #endif
-		}
-			catch (Exception e)
-			{
-				// Dispose method should never throw an exception
-				Debug.WriteLineIf(CLI.FnTrace.Enabled,
-					"OdbcConnection.Dispose caught exception: " + e.Message);
-			}
 		}
 
 		internal void Add (IntPtr hstmt, VirtuosoCommand command)
