@@ -1,7 +1,7 @@
 /*
  *  hosting_python.c
  *
- *  $Id: hosting_python.c,v 1.2.4.2 2011/01/12 00:33:29 source Exp $
+ *  $Id: hosting_python.c,v 1.2.2.1 2010/04/14 13:55:08 source Exp $
  *
  *  Virtuoso Python hosting plugin
  *  
@@ -109,15 +109,14 @@ start_python_interpreter (char *err, int max_len)
 
   PyEval_AcquireLock();
   tstate = Py_NewInterpreter ();
+  define_virtuoso_module (tstate->interp);
 
   if (!tstate)
     {
       SET_ERR ("Unable to start the Python interpretter");
     }
-
+  else
     interp = tstate->interp;
-  define_virtuoso_module (interp);
-
   PyThreadState_Clear (tstate);
   PyEval_ReleaseThread(tstate);
   PyThreadState_Delete (tstate);
