@@ -1,5 +1,5 @@
 /*
- *  $Id: rdf.js,v 1.15.2.8 2011/08/19 20:51:34 source Exp $
+ *  $Id: rdf.js,v 1.13.2.4 2010/06/28 09:35:57 source Exp $
  *
  *  This file is part of the OpenLink Software Ajax Toolkit (OAT) project.
  *
@@ -25,7 +25,7 @@ OAT.RDFAtom = function (tag, value, ns) {
     self._tag = tag;
     self._val = value;
     self._dt = '';
-    self._lang = false;
+    self._lang = '';
 
     this.isIRI = function () {
 	if (self._tag == OAT.RDFTag.IRI) return true;
@@ -50,10 +50,6 @@ OAT.RDFAtom = function (tag, value, ns) {
 	return self._val;
     }
 
-    this.getLang = function () {
-	return self._lang;
-    }
-
     this.equals = function (_obj) {
 	if (_obj.constructor != OAT.RDFAtom) return false;
 	if (_obj._tag != self._tag) return false;
@@ -66,7 +62,7 @@ OAT.RDFAtom = function (tag, value, ns) {
     //
 
     this.getValueDt = function () {
-	// XXX no-op
+
     }
 
     //
@@ -98,15 +94,9 @@ OAT.RDFAtom = function (tag, value, ns) {
     }
 	
     this.toString = function () {
-	var _out = "#ATOM:\{" + self.tagString(self._tag);
-	if (self.getTag() == OAT.RDFTag.IRI) {
-            _out += "IID:" + self._val + " " + "<" + OAT.IRIDB.getIRI (self._val) + ">";
-	}
-	if (self.getTag() == OAT.RDFTag.LIT) {
-	    _out += "\"" + self._val + "\"";
-	    var lang_tag = self.getLang();
-	    if (lang_tag) _out += "@" + lang_tag;
-	}
+	var _out = "#ATOM:\{" + self.tagString(self._tag) + " " + self._val + " "; 
+	if (self.getTag() == OAT.RDFTag.IRI) 
+	    _out = _out + "<" + OAT.IRIDB.getIRI (self._val) + ">";
 	return _out + "\}";
     }
 
@@ -125,29 +115,19 @@ OAT.RDFAtom = function (tag, value, ns) {
 // Global IRI repository
 // 
 
-
 OAT.IRIDB = {
-
-//
-// Some "Well-known" namespaces
-//
-
     _default_iris: [
-	["http://www.w3.org/1999/02/22-rdf-syntax-ns#", "rdf"],
-	["http://purl.org/dc/elements/1.1/",            "dc"],
-	["http://www.w3.org/2002/07/owl#",              "owl"],
 	["http://rdfs.org/sioc/ns#",                    "sioc"],
 	["http://www.w3.org/2000/01/rdf-schema#",       "rdfs"],
-        ["http://www.w3.org/2001/XMLSchema#",           "xsd"],
 	["http://xmlns.com/foaf/0.1/",                  "foaf"],
 	["http://umbel.org/umbel#",                     "umbel"],
-	["http://purl.org/goodrelations/v1#",           "gr"],
-	["http://www.openlinksw.com/schemas/xbrl/",     "xbrl"],
-	["http://www.openlinksw.com/schemas/rdfs/",     "oplrdfs"],
+	["http://purl.org/dc/elements/1.1/",            "dc"],
+	["http://www.w3.org/1999/02/22-rdf-syntax-ns#", "rdf"],
 	["http://dbpedia.org/resource/",                "dbpedia"],
+        ["http://www.w3.org/2001/XMLSchema#",           "xsd"],
+	["http://purl.org/goodrelations/v1#",           "gr"],
         ["http://dbpedia.org/ontology/",                "dbo"],
-        ["http://dbpedia.org/property/",                "dbpprop"],
-	["http://dbpedia.org/class/yago/",              "yago"]
+        ["http://dbpedia.org/property/",                "dbpprop"]
 ], // IRI array 
 
     _iri_a:  [],
@@ -158,7 +138,6 @@ OAT.IRIDB = {
     _ns_pref: {},
     _ciri_unres: [], // iids with unresolved CIRI
     _enableHTML5LocalStorage:false,
-    _ns_cnt: 0,  // count of "anon" ns pfxes
 
     //
     // Insert IRI, update ns prefix, or just get IID of existing IRI
@@ -173,7 +152,6 @@ OAT.IRIDB = {
 	    this._iri_a[iid] = [iri, (ns?ns:false)];
 	} else
 	    if (ns) {
-		if (typeof ns == "object") throw "InsertIRI error: Ciri cannot be an object.";
 		this._iri_a[iid][1] = ns;
 	    }
 	return iid;
@@ -182,7 +160,7 @@ OAT.IRIDB = {
     insertIRIArr: function (iri_arr) {
 	var r_a = []; 
 	for (var i=0;i<iri_arr.length;i++) {
-	    if (typeof iri_arr[i] == 'object') {
+	    if (typeof iri_arr[i] == 'Object') {
 		r_a.push (this.insertIRI (iri_arr[i][0], iri_arr[i][1]));
 	    } 
 	    else {
@@ -222,6 +200,11 @@ OAT.IRIDB = {
 	return (iri_id ? iri_id : false);
     },
 
+    getCIRIByID: function (iid) {
+	var i_a = this._iri_a[iid];
+	return ((i_a && i_a[1]) ? i_a[1] : false);
+    },
+
 //
 // Resolve an IRI to a CIRI representation
 //
@@ -233,7 +216,6 @@ OAT.IRIDB = {
     },
 
     splitIRI:function (iri) {
-	if (typeof iri != "string") throw "splitIRI: invalid iri - must be string";
 	var r = iri.match(/([^\/#]+)[\/#]?$/);
 	if (r && r[1] == "this") {
 	    r = iri.match(/([^\/#]+)#[^#]*$/);
@@ -241,14 +223,6 @@ OAT.IRIDB = {
 	return (r ? r : false);
     }, 
 
-    makeNSPrefix:function() {
-	return 'ns'+this._ns_cnt++;
-    },
-
-    //
-    //  Resolve CIRI (IRI with NS Prefix) and cache
-    //
-
     resolveCIRI:function (iid) {
 	var ciri = this._iri_a[iid][1];
 	if (!!ciri) return ciri;
@@ -257,28 +231,18 @@ OAT.IRIDB = {
 
 	var i_a = this.splitIRI (iri); // http://www.zonk.net/onto/cli/ 
 	
-	var ns_iri = iri.substr(0, i_a.index);
-	var ns_iid = this._iri_h [ns_iri];
+	var pfx_str = iri.substr(0, i_a.index);
+	var pfx_iid = this._iri_h [pfx_str];
 
-	if (ns_iid) {
-            if (this._iri_a[ns_iid][1]) {
-		ciri = this._iri_a[ns_iid][1] + ":" + i_a[0]; // Already have a ns prefix
-	    } else {
-		var new_ns = this.makeNSPrefix(); // ns IRI exists but no prefix - synthesize and save
-		ciri = new_ns + ':' + i_a[0];
-		this._iri_a[ns_iid][1] = new_ns;
-	    }
-	}
-	else
+	if (pfx_iid)
 	    {
-	    var new_ns = this.makeNSPrefix();
-	    this.insertIRI(ns_iri, new_ns);
-	    ciri = new_ns + ":" + i_a[0];	    
+		ciri = this._iri_a[pfx_iid][1] + ":" + i_a[0];
+		this._iri_a[iid][1] = ciri; 
+
+		return ciri;
 	    }
 
-	this._iri_a[iid][1] = ciri; // cache CIRI with the IRI
-
-	return ciri;
+	return false;
     },
 
     init: function () {
@@ -294,14 +258,11 @@ OAT.IRIDB = {
 		OAT.IRIDB._iri_h = idb._iri_h;
 		OAT.IRIDB._iri_c = idb._iri_c;
 		OAT.IRIDB._iri_d = idb._iri_d;
-	    } else {
-	    this.insertIRIArr (this._default_iris);
-		this.save();
 	    }
+	    this.insertIRIArr (this._default_iris);
+	    
 	    OAT.MSG.attach ("*","OAT_RDF_STORE_LOADED", this.save);
 	}
-	else
-	    this.insertIRIArr (this._default_iris);
     },	    
 
     getStats: function () {
@@ -528,14 +489,14 @@ OAT.RDF = {
 
 		    var obj = a.nodeValue;
 
-		    var objNs = OAT.Xml.getNsURI (a);
+		    var objNs = OAT.Xml.getNsURL (a);
 		    var objNsPrefix = OAT.Xml.getNsPrefix(obj);
 
 		    OAT.IRIDB.insertIRI(objNs, objNsPrefix);
 
 		    triples.push([OAT.IRIDB.insertIRI(subj),
 				  OAT.IRIDB.insertIRI(pred),
-				  new OAT.RDFAtom (OAT.RDFTag.IRI, OAT.IRIDB.insertIRI(obj), objNs)]);
+				  new OAT.RDFAtom (OAT.RDFTag.IRI, OAT.IRIDB.insertIRI(obj), ns)]);
 		}
 	    } /* for all attributes */
 	    
@@ -615,21 +576,7 @@ OAT.RDF = {
 	
 	for (var i=0;i<root.childNodes.length;i++) {
 	    var node = root.childNodes[i];
-	    if (node.nodeType == 1) { 
-		if (OAT.Xml.localName(node) == "parsererror") { // Handle WebKit Parse error
-		    var error_m = node.innerText ? node.innerText : "Unknown Error";
-
-		    // XXX: This is probably not a good idea - should just throw an exception?
-
-		    if (!url.match(/#[a-zA-Z0-9]*$/)) url += '#parseErrorInQueryResult';
-		    
-		    triples.push ([OAT.IRIDB.insertIRI(url),
-				   OAT.IRIDB.insertIRI("http://www.openlinksw.com/schema/oat/hasRdfParserError"),
-				   new OAT.RDFAtom (OAT.RDFTag.LIT, error_m)]);
-		} else {
-		    processNode(node); 
-		}
-	    }
+	    if (node.nodeType == 1) { processNode(node); }
 	}
 	return triples;
 	}
@@ -857,4 +804,4 @@ OAT.N3 = {
 	return triples;
     }
 }
-// OAT.N3
\ No newline at end of file
+// OAT.N3
