@@ -1,9 +1,9 @@
 /*
- *  $Id: tree.js,v 1.19.2.1 2010/01/14 15:57:40 source Exp $
+ *  $Id: tree.js,v 1.19.2.4 2010/04/06 16:46:12 source Exp $
  *
  *  This file is part of the OpenLink Software Ajax Toolkit (OAT) project.
  *
- *  Copyright (C) 2005-2009 OpenLink Software
+ *  Copyright (C) 2005-2010 OpenLink Software
  *
  *  See LICENSE file for details.
  */
@@ -12,9 +12,9 @@
 	t = new OAT.Tree(options);
 	t.assign(listElm,collapse);
 	t.delete();
-	
+
 	var node = t.tree.children[index]
-	
+
 	node.select()
 	node.deselect()
 	node.expand()
@@ -27,7 +27,7 @@
 	node.appendChild(oldNode, [index])
 	node.deleteChild(oldNode)
 	node.createChild(label, isNode, [index])
-	
+
 */
 
 OAT.TreeNode = function(li,ul,parent,root,value) {
@@ -50,10 +50,10 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 	this._label = OAT.Dom.create("span"); /* label */
 	this._gdElm = OAT.Dom.create("span"); /* icon+label */
 	if (ul) { ul.style.listStyleType = "none"; }
-	self._div.obj = self; 
+	self._div.obj = self;
 	this.hasEvents = false;
 	this.gdMode = 0;
-	
+
 	/* create structure:
 		<li>
 			<div>
@@ -80,22 +80,22 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 		}
 		OAT.Dom.clear(self.li);
 		OAT.Dom.append([self._gdElm,self._label],[self._div,self._gdElm],[self.li,self._div]);
-		if (self.ul) { 
-			self.li.appendChild(self.ul); 
+		if (self.ul) {
+			self.li.appendChild(self.ul);
 		}
 	}
-	
+
 	if (self.ul) { /* margin & padding */
 		self.ul.style.margin = "0px";
 		self.ul.style.padding = "0px";
 		if (self.parent) { self.ul.style.marginLeft = "-16px"; }
 	}
-	
+
 	if (self.options.checkboxMode && self.li) { /* checkboxes */
 		self.checkbox = OAT.Dom.create("input",{verticalAlign:"middle"});
 		self.checkbox.type = "checkbox";
-		if (self.options.defaultCheck) { 
-			self.checkbox.checked = true; 
+		if (self.options.defaultCheck) {
+			self.checkbox.checked = true;
 			self.checkbox.__checked = "1";
 		}
 		if (self.checkbox.checked == self.options.checkNOI) {
@@ -110,7 +110,7 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 			if (a.nodeName == "oat:treeimage") { self.customImage = a.nodeValue; }
 		}
 	}
-	
+
 	this.toggleCheck = function(event) {
 		/* 1. toggle checkbox for all descendant nodes, 2. actualize checked list, 3. callback */
 		if (self.checkbox.checked) {
@@ -119,32 +119,32 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 		} else {
 			self.checkbox.__checked = "0";
 		}
-		if (self.ul) { 
+		if (self.ul) {
 			var func = (self.checkbox.checked ? "checkAll" : "uncheckAll");
 			self.walk(func);
 		}
-		
+
 		self.root.checkedNOI = [];
 		self.root.walk("updateNOI");
-		
+
 		self.options.checkCallback(self.root.checkedNOI);
 	}
-	
+
 	this.updateNOI = function() {
 		var ch = (self.checkbox.__checked == "1" || self.checkbox.checked);
 		if (ch == self.options.checkNOI) { self.root.checkedNOI.push(self); }
 	}
-	
+
 	this.checkAll = function() {
 		self.checkbox.checked = true;
 		self.checkbox.__checked = "1";
 	}
-	
+
 	this.uncheckAll = function() {
 		self.checkbox.checked = false;
 		self.checkbox.__checked = "0";
 	}
-	
+
 	this.checkUp = function(firstLevel) {
 		if (self.checkbox.checked && !firstLevel) { return; }
 		if (!firstLevel) {
@@ -153,11 +153,11 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 		}
 		if (self.parent && self.parent.li) { self.parent.checkUp(false); }
 	}
-	
+
 	this.toggleState = function(event) {
 		self.state ? self.collapse() : self.expand();
 	}
-	
+
 	this.toggleSelect = function(event) {
 		if (event.ctrlKey || (OAT.Browser.isMac && event.metaKey)) {
 			if (self.selected) { self.deselect(); } else { self.select(); }
@@ -166,7 +166,7 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 			self.select();
 		}
 	}
-	
+
 	this.select = function() {
 		self.selected = 1;
 		self.root.selectedNodes.push(self);
@@ -174,23 +174,23 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 		if (self.ul) { OAT.Dom.addClass(self.ul,"tree_ul_selected"); }
 		self.updateStyle();
 	}
-	
+
 	this.deselect = function() {
 		self.selected = 0;
-		var index = self.root.selectedNodes.find(self);
+		var index = self.root.selectedNodes.indexOf(self);
 		self.root.selectedNodes.splice(index,1);
 		OAT.Dom.removeClass(self.li,"tree_li_selected");
 		if (self.ul) { OAT.Dom.removeClass(self.ul,"tree_ul_selected"); }
 		self.updateStyle();
 	}
-	
+
 	this.firstSync = function(depth) {
 		self.depth = depth;
 		self.addDecorations();
 		self.addEvents();
 		self.updateStyle();
 	}
-	
+
 	this.sync = function(depth) {
 		self.removeEvents();
 		self.removeDecorations();
@@ -199,11 +199,11 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 		self.addEvents();
 		self.updateStyle();
 	}
-	
+
 	this.removeEvents = function() {
 		if (!self.li) { return; }
 		if (!self.hasEvents) { return; } /* nothing to remove */
-		
+
 		switch (self.options.onClick) {
 			case "select":
 				if (!self.options.poorMode) {
@@ -211,7 +211,7 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 					OAT.Event.detach(self._icon,"click",self.toggleSelect);
 				}
 			break;
-			
+
 			case "toggle":
 				if (self.ul) {
 					OAT.Event.detach(self._label,"click",self.toggleState);
@@ -219,7 +219,7 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 				}
 			break;
 		}
-		
+
 		switch (self.options.onClick) {
 			case "select":
 				if (!self.options.poorMode) {
@@ -227,7 +227,7 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 					OAT.Event.detach(self._icon,"dblclick",self.toggleSelect);
 				}
 			break;
-			
+
 			case "toggle":
 				if (self.ul) {
 					OAT.Event.detach(self._label,"dblclick",self.toggleState);
@@ -235,23 +235,23 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 				}
 			break;
 		}
-		
+
 		if (self.options.poorMode) { return; }
 
 		if (self.ul) { OAT.Event.detach(self._sign,"click",self.toggleState); } /* +- sign */
-		
+
 		if (self.options.checkboxMode) { OAT.Event.detach(self.checkbox,"change",self.toggleCheck); }
-		
+
 		if (self.options.allowDrag) {
 			self.root.gd.delTarget(self._gdElm);
 			self.root.gd.delSource(self._gdElm);
 		}
 	}
-	
+
 	this.addEvents = function() {
 		self.hasEvents = true;
 		if (!self.li) { return; }
-		
+
 		switch (self.options.onClick) {
 			case "select":
 				if (!self.options.poorMode) {
@@ -259,7 +259,7 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 					OAT.Event.attach(self._icon,"click",self.toggleSelect);
 				}
 			break;
-			
+
 			case "toggle":
 				if (self.ul) {
 					OAT.Event.attach(self._label,"click",self.toggleState);
@@ -267,7 +267,7 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 				}
 			break;
 		}
-		
+
 		switch (self.options.onDblClick) {
 			case "select":
 				if (!self.options.poorMode) {
@@ -275,7 +275,7 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 					OAT.Event.attach(self._icon,"dblclick",self.toggleSelect);
 				}
 			break;
-			
+
 			case "toggle":
 				if (self.ul) {
 					OAT.Event.attach(self._label,"dblclick",self.toggleState);
@@ -287,12 +287,12 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 		if (self.options.poorMode) { return; }
 
 		if (self.ul) { OAT.Event.attach(self._sign,"click",self.toggleState); } /* +- sign */
-		
+
 		/* if checkbox mode is used */
 		if (self.options.checkboxMode) { OAT.Event.attach(self.checkbox,"change",self.toggleCheck); }
-		
+
 		if (!self.options.allowDrag) { return; }
-		
+
 		var procRef = function(elm) {}
 		var backRef = function(target,x,y) { /* ghostdrag ended; some re-structuring? */
 			var node = target.obj;
@@ -309,15 +309,15 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 			var mode = node.gdMode;
 
 			function isLast(n) {
-				return (n.parent.children.find(n) == n.parent.children.length-1);
+				return (n.parent.children.indexOf(n) == n.parent.children.length-1);
 			}
-			
+
 			if (mode == 1) {
 				/* check appending after last node */
 				while (node.parent && node.parent.parent && isLast(node)) { node = node.parent; }
-			
+
 				/* reposition after target */
-				var index = node.parent.children.find(node)+1;
+				var index = node.parent.children.indexOf(node)+1;
 				node.parent.appendChild(self,index);
 			} else {
 				/* append */
@@ -330,7 +330,7 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 			self.root.gd.addSource(self._gdElm,procRef,backRef);
 		}
 	}
-	
+
 	this.removeDecorations = function() {
 		if (!self.li) { return; }
 		if (self.options.poorMode) { return; }
@@ -345,37 +345,37 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 			self._icon = false;
 		}
 	}
-	
+
 	this.addDecorations = function() {
 		if (!self.li) { return; }
-		
+
 		OAT.Dom.addClass(self.li,"tree_li_"+self.depth);
 		OAT.Dom.addClass(self.li.parentNode,"tree_ul_"+self.depth);
 
 		if (self.options.poorMode) { return; }
-		
+
 		var sign = OAT.Dom.create("img",{width:self.options.size+"px",height:self.options.size+"px",verticalAlign:"middle"});
 
 		self._div.insertBefore(sign,self._gdElm);
-		
+
 		if (self.options.checkboxMode) {
 			var icon = false;
-		} else {	
+		} else {
 			var icon = OAT.Dom.create("img",{width:self.options.size+"px",height:self.options.size+"px",verticalAlign:"middle"});
 			icon.style.marginRight = "2px";
 			self._gdElm.insertBefore(icon,self._label);
 		}
 		self._sign = sign;
 		self._icon = icon;
-		
+
 		if (self.parent.children[self.parent.children.length-1] == self) { OAT.Dom.addClass(self.li,"tree_li_last"); }
 	}
-	
+
 	this.setImage = function(newImage) {
 		self.customImage = newImage;
 		self.updateStyle();
 	}
-	
+
 	this.expand = function(silent) {
 		if (self.options.onlyOneOpened) {
 			/* close all opened siblings */
@@ -386,9 +386,9 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 		}
 		self.state = 1;
 		self.updateStyle();
-		if (!silent) { OAT.MSG.send(self.root,OAT.MSG.TREE_EXPAND,self); }
+		if (!silent) { OAT.MSG.send(self.root,"TREE_EXPAND",self); }
 	}
-	
+
 	this.collapse = function() {
 		/* check children for selection. if at lease one descendant is selected, select this node */
 		if (self.options.ascendSelection) {
@@ -399,18 +399,18 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 		}
 		self.state = 0;
 		self.updateStyle();
-		OAT.MSG.send(self.root,OAT.MSG.TREE_COLLAPSE,self);
+		OAT.MSG.send(self.root,"TREE_COLLAPSE",self);
 	}
-	
+
 	this.testForSelected = function() {
 		var selected = [];
 		if (self.selected) { selected.push(self); }
-		for (var i=0;i<self.children.length;i++) { 
+		for (var i=0;i<self.children.length;i++) {
 			selected.append(self.children[i].testForSelected());
 		}
 		return selected;
 	}
-	
+
 	this.updateStyle = function() { /* adjust icon contents as needed */
 		var signName = "blank";
 		if (self.ul) { /* unless specified otherwise, all non-leaf nodes are expanded */
@@ -441,36 +441,36 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 			if (self._icon) { self._icon.style.cursor = ""; }
 			if (self._sign) { self._sign.style.cursor = ""; }
 		}
-		
+
 		if (self.customImage) {
 			iconName = self.customImage;
 		}
-		
+
 		self.applyImage(self._icon,iconName);
 		self.applyImage(self._sign,signName);
-		if (self.options.useDots && self.li) { 
+		if (self.options.useDots && self.li) {
 			var dots = (self.parent.children[self.parent.children.length-1] == self ? "dots-part" : "dots-full");
 			self.applyBackground(self.li,dots);
 			self.li.style.backgroundRepeat = (dots == "dots-full" ? "repeat-y" : "no-repeat");
-			self.applyBackground(self._sign,"dots-horiz"); 
+			self.applyBackground(self._sign,"dots-horiz");
 		}
-		
+
 	}
-	
+
 	this.walk = function(methodName,depth) {
 		self[methodName](depth);
 		for (var i=0;i<self.children.length;i++) {
 			self.children[i].walk(methodName,depth+1);
 		}
 	}
-	
+
 	this.applyBackground = function(img,name) {
 		if (!img) { return; }
 		var o = self.options;
 		var path = o.imagePath + "Tree_" + (o.imagePrefix=="" ? "" : o.imagePrefix+"_") + name + ".gif";
 		img.style.backgroundImage = 'url("'+path+'")';
 	}
-	
+
 	this.applyImage = function(img,name) {
 		if (!img) { return; }
 		var o = self.options;
@@ -485,19 +485,19 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 		var pathB = o.imagePath + "Blank.gif";
 		OAT.Dom.imageSrc(img,path,pathB);
 	}
-	
+
 	this.appendChild = function(oldNode,index,ignoreOldParent) {
 		/* insert before node at position [index] */
 		var idx = ( (index || index == 0) ? index : self.children.length);
 		var oldParent = oldNode.parent;
-		if (!ignoreOldParent) { var oldIdx = oldParent.children.find(oldNode); }
+		if (!ignoreOldParent) { var oldIdx = oldParent.children.indexOf(oldNode); }
 		/* basic check */
 		if (!self.ul) {
 			self.ul = OAT.Dom.create("ul",{margin:"0px",padding:"0px"});
 			self.li.appendChild(self.ul);
 			self.ul.style.listStyleType = "none";
 		}
-		
+
 		/* 1. DOM */
 		if (self.children.length && idx < self.children.length) {
 			var afterSibling = self.children[idx];
@@ -513,22 +513,22 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 			oldParent.children.splice(oldIdx,1);
 		}
 		oldNode.parent = self;
-		
+
 		/* remaining bits */
 		self.root.walk("sync");
 	}
-	
+
 	this.deleteChild = function(oldNode) {
-		var index = self.children.find(oldNode);
+		var index = self.children.indexOf(oldNode);
 		if (index == -1) { return; }
 		self.children.splice(index,1);
 		OAT.Dom.unlink(oldNode.li);
 	}
-	
+
 	this.createChild = function(label,isNode,index,value) {
 		var li = OAT.Dom.create("li");
 		var ul = false;
-		if (isNode) { 
+		if (isNode) {
 			var ul = OAT.Dom.create("ul");
 			li.appendChild(ul);
 		}
@@ -538,7 +538,7 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 		self.appendChild(child,index,true);
 		return child;
 	}
-	
+
 	this.setLabel = function(newLabel) { self._label.innerHTML = newLabel; }
 	this.getLabel = function() { return self._label.innerHTML; }
 
@@ -550,20 +550,20 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 		self._label.style.fontWeight = "normal";
 		self._div.style.borderBottom = "none";
 	}
-	
+
 	this.checkSignal = function() {
 		var e = self.root.gdEvent;
 		var pos = OAT.Dom.position(self._div);
 		var dims = OAT.Dom.getWH(self._div);
 		var epos = OAT.Event.position(e);
-		
+
 		var hit = 0;
-		
+
 		if (epos[0] > pos[0] && epos[0] < pos[0]+dims[0] &&
 			epos[1] > pos[1] && epos[1] < pos[1]+dims[1]) {
 			hit = 1;
 		}
-		
+
 		if (!hit) {
 			if (self.gdMode) { self.removeSignal(); }
 			return;
@@ -576,8 +576,8 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 			epos[1] > pos[1] && epos[1] < pos[1]+dims[1]) {
 			hit = 2;
 		}
-		
-		
+
+
 		if (hit == 2 && self.ul) {
 			self._label.style.fontWeight = "bold";
 			self._div.style.borderBottom = "none";
@@ -587,9 +587,9 @@ OAT.TreeNode = function(li,ul,parent,root,value) {
 			self._div.style.borderBottom = "1px dotted #888";
 			self.gdMode = 1;
 		}
-		
+
 	}
-	
+
 	return self;
 }
 
@@ -606,69 +606,69 @@ OAT.Tree = function(optObj) {
 		useDots:true,
 		onClick:"select", /* select|toggle|false */
 		onDblClick:"toggle", /* select|toggle|false */
-		
+
 		poorMode:false, /* performance increase */
-		
+
 		checkboxMode:false, /* checkboxes instead of filders */
 		defaultCheck:true, /* checkboxes checked by default? */
 		checkNOI:true, /* Nodes Of Interest: true == checked, false == unchecked */
-		checkCallback:function(){} 
+		checkCallback:function(){}
 	}
 	this.tree = false; /* data structure */
 	this.selectedNodes = [];
 	this.checkedNOI = [];
-	
+
 	this.gd = new OAT.GhostDrag();
-	
+
 	for (var p in optObj) { self.options[p] = optObj[p]; }
-	
+
 	this.dragging = false;
-	
+
 	this.gdStart = function() {
 		self.dragging = true;
 	}
-	
+
 	this.gdEnd = function() {
 		self.dragging = false;
 		self.walk("removeSignal");
 	}
-	
+
 	this.gdMove = function(event) {
 		if (!self.dragging) { return; }
 		self.gdEvent = event;
 		self.walk("checkSignal")
 	}
-	
-	this.walk = function(methodName) { 
-		for (var i=0;i<self.tree.children.length;i++) { 
-			self.tree.children[i].walk(methodName,1); 
-		} 
+
+	this.walk = function(methodName) {
+		for (var i=0;i<self.tree.children.length;i++) {
+			self.tree.children[i].walk(methodName,1);
+		}
 	}
-	
+
 	this.assign = function(listElm,collapse) {
 		var ul = $(listElm);
 		ul.style.listStyleType = "none";
-		
-		if (self.options.allowDrag) { 
-			OAT.MSG.attach(self.gd,OAT.MSG.GD_START,self.gdStart);
-			OAT.MSG.attach(self.gd,OAT.MSG.GD_END,self.gdEnd);
-			OAT.MSG.attach(self.gd,OAT.MSG.GD_ABORT,self.gdEnd);
+
+		if (self.options.allowDrag) {
+			OAT.MSG.attach(self.gd,"GD_START",self.gdStart);
+			OAT.MSG.attach(self.gd,"GD_END",self.gdEnd);
+			OAT.MSG.attach(self.gd,"GD_ABORT",self.gdEnd);
 			OAT.Event.attach(document,"mousemove",self.gdMove);
 		}
-		
+
 		/* get a mirror of existing structure */
 		self.tree = new OAT.TreeNode(false,ul,false,self,false);
 		var list = ul.childNodes;
 		for (var i=0;i<list.length;i++) {
-			if (list[i].tagName && list[i].tagName.toLowerCase() == "li") { 
+			if (list[i].tagName && list[i].tagName.toLowerCase() == "li") {
 				var child = self.scanList(list[i],self.tree);
-				self.tree.children.push(child); 
+				self.tree.children.push(child);
 			}
 		}
 		self.walk("firstSync");
 		if (collapse) { self.walk("collapse"); }
 	}
-	
+
 	this.scanList = function(node,parent) {
 		/* find child ul if exists */
 		var candidate = false;
@@ -679,15 +679,14 @@ OAT.Tree = function(optObj) {
 
 		var obj = new OAT.TreeNode(node,candidate,parent,self);
 		if (!candidate) { return obj; }
-		
+
 		var list = candidate.childNodes;
 		for (var i=0;i<list.length;i++) {
-			if (list[i].tagName && list[i].tagName.toLowerCase() == "li") { 
+			if (list[i].tagName && list[i].tagName.toLowerCase() == "li") {
 				var child = self.scanList(list[i],obj);
-				obj.children.push(child); 
+				obj.children.push(child);
 			}
 		}
 		return obj;
 	}
 }
-OAT.Loader.featureLoaded("tree");
