@@ -1,10 +1,10 @@
 /*
- *  $Id: VirtuosoRepository.java,v 1.9.2.5 2009/12/22 15:50:23 source Exp $
+ *  $Id: VirtuosoRepository.java,v 1.9.2.8 2010/06/28 10:31:24 source Exp $
  *
  *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
  *  project.
  *
- *  Copyright (C) 1998-2007 OpenLink Software
+ *  Copyright (C) 1998-2010 OpenLink Software
  *
  *  This project is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -33,7 +33,7 @@ import org.openrdf.repository.Repository;
 import org.openrdf.repository.RepositoryConnection;
 import org.openrdf.repository.RepositoryException;
 
-import virtuoso.jdbc4.VirtuosoConnectionPoolDataSource;
+import virtuoso.jdbc3.VirtuosoConnectionPoolDataSource;
 
 /**
  * A Sesame repository that contains RDF data that can be queried and updated.
@@ -66,6 +66,7 @@ public class VirtuosoRepository implements Repository {
 	boolean useLazyAdd = false;
 	String defGraph;
 	int prefetchSize = 200;
+	String ruleSet;
 	
 	/**
 	 * Construct a VirtuosoRepository with a specified parameters
@@ -95,7 +96,6 @@ public class VirtuosoRepository implements Repository {
          *
 	 */
 	public VirtuosoRepository(String url_hostlist, String user, String password, String defGraph, boolean useLazyAdd) {
-
 	        super();
 		this.url_hostlist = url_hostlist.trim();
 		this.user = user;
@@ -205,7 +205,7 @@ public class VirtuosoRepository implements Repository {
 	public RepositoryConnection getConnection() throws RepositoryException {
 		if (url_hostlist.startsWith("jdbc:virtuoso://")) {
 			try {
-				Class.forName("virtuoso.jdbc4.Driver");
+				Class.forName("virtuoso.jdbc3.Driver");
 				String url = url_hostlist;
 				if (url.toLowerCase().indexOf(utf8) == -1) {
 	   				if (url.charAt(url.length()-1) != '/')
@@ -282,6 +282,26 @@ public class VirtuosoRepository implements Repository {
 	}
 
 	
+	/**
+	 * Set inference RuleSet name
+	 * 
+	 * @param name
+	 *        RuleSet name.
+	 */
+	public void setRuleSet(String name) {
+		if (name != null && name.equals("null"))
+		  	name = null;
+		this.ruleSet = name;
+	}
+
+	/**
+	 * Get the RoundRobin state for connection
+	 */
+	public String getRuleSet() {
+		return this.ruleSet;
+	}
+
+	
 	/**
 	 * Get the directory where data and logging for this repository is stored.
 	 * 
@@ -352,4 +372,18 @@ public class VirtuosoRepository implements Repository {
 		this.resultsHandlerType = handlerType;
 	}
 
+        public void createRuleSet(String ruleSetName, String uriGraphRuleSet) throws RepositoryException
+        {
+          java.sql.Connection con = ((VirtuosoRepositoryConnection)getConnection()).getQuadStoreConnection();
+
+          try {
+	    java.sql.Statement st = con.createStatement();
+	    st.execute("rdfs_rule_set('"+ruleSetName+"', '"+uriGraphRuleSet+"')");
+	    st.close();
+          } catch (Exception e) {
+            throw new RepositoryException(e);
+          }
+        }
+
+
 }
