@@ -1,10 +1,10 @@
 /*
- *  $Id: VirtuosoRepositoryConnection.java,v 1.33.2.5 2009/12/22 15:50:23 source Exp $
+ *  $Id: VirtuosoRepositoryConnection.java,v 1.33.2.12 2010/07/05 12:41:21 source Exp $
  *
  *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
  *  project.
  *
- *  Copyright (C) 1998-2007 OpenLink Software
+ *  Copyright (C) 1998-2010 OpenLink Software
  *
  *  This project is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -151,7 +151,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	private static Resource nilContext;
 	private Connection quadStoreConnection;
 	protected VirtuosoRepository repository;
-	static final String S_INSERT = "sparql define output:format '_JAVA_'  insert into graph iri(??) { `iri(??)` `iri(??)` `bif:__rdf_long_from_batch_params(??,??,??)` }";
+	static final String S_INSERT = "sparql define output:format '_JAVA_' insert into graph iri(??) { `iri(??)` `iri(??)` `bif:__rdf_long_from_batch_params(??,??,??)` }";
         static final String S_DELETE = "sparql define output:format '_JAVA_' delete from graph iri(??) {`iri(??)` `iri(??)` `bif:__rdf_long_from_batch_params(??,??,??)`}";
 	static final int BATCH_SIZE = 5000;
 	private PreparedStatement psInsert;
@@ -278,19 +278,15 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 		      break;
 		}
 
-		if(type.equals("select")) {
+		flushDelayAdd();
+		if(type.equals("select"))
 			return prepareTupleQuery(language, query, baseURI);
-		}
-		else if(type.equals("construct") || type.equals("describe")) {
+		else if(type.equals("construct") || type.equals("describe"))
 			return prepareGraphQuery(language, query, baseURI);
-		}
-		else if(type.equals("ask")) {
+		else if(type.equals("ask"))
 			return prepareBooleanQuery(language, query, baseURI);
-		}
-		else {
-			sendDelayAdd();
+		else
 			return new VirtuosoQuery();
-		}
 	}
 
 	/**
@@ -335,11 +331,11 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	public TupleQuery prepareTupleQuery(QueryLanguage langauge, final String query, String baseeURI) throws RepositoryException, MalformedQueryException {
 		TupleQuery q = new VirtuosoTupleQuery() {
 			public TupleQueryResult evaluate() throws QueryEvaluationException {
-				return executeSPARQLForTupleResult(query, getDataset());
+				return executeSPARQLForTupleResult(query, getDataset(), getIncludeInferred(), getBindings());
 			}
 
 			public void evaluate(TupleQueryResultHandler handler) throws QueryEvaluationException, TupleQueryResultHandlerException {
-				executeSPARQLForHandler(handler, query, getDataset());
+				executeSPARQLForHandler(handler, query, getDataset(), getIncludeInferred(), getBindings());
 			}
 		};
 		return q;
@@ -387,11 +383,11 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	public GraphQuery prepareGraphQuery(QueryLanguage language, final String query, String baseURI) throws RepositoryException, MalformedQueryException {
 		GraphQuery q = new VirtuosoGraphQuery() {
 			public GraphQueryResult evaluate() throws QueryEvaluationException {
-				return executeSPARQLForGraphResult(query, getDataset());
+				return executeSPARQLForGraphResult(query, getDataset(), getIncludeInferred(), getBindings());
 			}
 
 			public void evaluate(RDFHandler handler) throws QueryEvaluationException, RDFHandlerException {
-				executeSPARQLForHandler(handler, query, getDataset());
+				executeSPARQLForHandler(handler, query, getDataset(), getIncludeInferred(), getBindings());
 			}
 		};
 		return q;
@@ -439,7 +435,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	public BooleanQuery prepareBooleanQuery(QueryLanguage language, final String query, String baseURI) throws RepositoryException, MalformedQueryException {
 		BooleanQuery q = new VirtuosoBooleanQuery() {
 			public boolean evaluate() throws QueryEvaluationException {
-				return executeSPARQLForBooleanResult(query, getDataset());
+				return executeSPARQLForBooleanResult(query, getDataset(), getIncludeInferred(), getBindings());
 			}
 		};
 		return q;
@@ -455,7 +451,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	 */
 	public RepositoryResult<Resource> getContextIDs() throws RepositoryException {
 		verifyIsOpen();
-		sendDelayAdd();
+		flushDelayAdd();
 		Vector<Resource> v = new Vector<Resource>();
 		String query = "DB.DBA.SPARQL_SELECT_KNOWN_GRAPHS()";
 		try {
@@ -670,7 +666,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	public long size(Resource... contexts) throws RepositoryException {
 		int ret = 0;
 		verifyIsOpen();
-		sendDelayAdd();
+		flushDelayAdd();
 
 		contexts = checkContext(contexts);
 		StringBuffer query = new StringBuffer("select count(*) from (sparql define input:storage \"\" select * ");
@@ -690,7 +686,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
                         rs.close();
 		}
 		catch (Exception e) {
-			throw new RepositoryException(e);
+			throw new RepositoryException(": SPARQL execute failed:["+query+"] \n Exception:"+e);
 		}
 		return ret;
 	}
@@ -706,7 +702,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	 */
 	public boolean isEmpty() throws RepositoryException {
 		verifyIsOpen();
-		sendDelayAdd();
+		flushDelayAdd();
 		boolean result = false;
 		String query = "sparql define input:storage \"\" select * where {?s ?o ?p} limit 1";
 		try {
@@ -717,7 +713,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
                         return result;
 		}
 		catch (Exception e) {
-			throw new RepositoryException("Problem executing query: " + query, e);
+			throw new RepositoryException(": SPARQL execute failed:["+query+"] \n Exception:"+e);
 		}
 	}
 
@@ -738,7 +734,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	 */
 	public void setAutoCommit(boolean autoCommit) throws RepositoryException {
 		verifyIsOpen();
-		sendDelayAdd();
+		flushDelayAdd();
 
 		try {
 			getQuadStoreConnection().setAutoCommit(autoCommit);
@@ -772,7 +768,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	 */
 	public void commit() throws RepositoryException {
 		verifyIsOpen();
-		sendDelayAdd();
+		flushDelayAdd();
 		try {
 			getQuadStoreConnection().commit();
 		}
@@ -1255,7 +1251,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	public void remove(Resource subject, URI predicate, Value object, Resource... contexts) throws RepositoryException {
 		OpenRDFUtil.verifyContextNotNull(contexts);
 	        verifyIsOpen();
-		sendDelayAdd();
+		flushDelayAdd();
 
 		contexts = checkDMLContext(contexts);
 		boolean autoCommit = isAutoCommit();
@@ -1318,7 +1314,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	public void remove(Iterable<? extends Statement> statements, Resource... contexts) throws RepositoryException {
 		OpenRDFUtil.verifyContextNotNull(contexts);
 		verifyIsOpen();
-		sendDelayAdd();
+		flushDelayAdd();
 
 		Resource[] _contexts;
 		Iterator<? extends Statement> it = statements.iterator();
@@ -1374,7 +1370,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	public <E extends Exception> void remove(Iteration<? extends Statement, E> statements, Resource... contexts) throws RepositoryException, E {
 		OpenRDFUtil.verifyContextNotNull(contexts);
 		verifyIsOpen();
-		sendDelayAdd();
+		flushDelayAdd();
 
 		Resource[] _contexts;
 		boolean autoCommit = isAutoCommit();
@@ -1420,7 +1416,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	public void clear(Resource... contexts) throws RepositoryException {
 		OpenRDFUtil.verifyContextNotNull(contexts);
 		verifyIsOpen();
-		sendDelayAdd();
+		flushDelayAdd();
 
 		contexts = checkDMLContext(contexts);
 
@@ -1452,7 +1448,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	 */
 	public RepositoryResult<Namespace> getNamespaces() throws RepositoryException {
 		verifyIsOpen();
-		sendDelayAdd();
+		flushDelayAdd();
 		List<Namespace> namespaceList = new LinkedList<Namespace>();
 		String query = "DB.DBA.XML_SELECT_ALL_NS_DECLS (3)";
 		try {
@@ -1488,7 +1484,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	 */
 	public String getNamespace(String prefix) throws RepositoryException {
 		verifyIsOpen();
-		sendDelayAdd();
+		flushDelayAdd();
 		String retVal = null;
 		String query = "SELECT __xml_get_ns_uri (?, 3)";
 		try {
@@ -1522,7 +1518,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	 */
 	public void setNamespace(String prefix, String name) throws RepositoryException {
 		verifyIsOpen();
-		sendDelayAdd();
+		flushDelayAdd();
 		String query = "DB.DBA.XML_SET_NS_DECL(?, ?, 1)";
 		try {
 			PreparedStatement ps = getQuadStoreConnection().prepareStatement(query);
@@ -1547,7 +1543,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	 */
 	public void removeNamespace(String prefix) throws RepositoryException {
 		verifyIsOpen();
-		sendDelayAdd();
+		flushDelayAdd();
 		String query = "DB.DBA.XML_REMOVE_NS_BY_PREFIX(?, 1)";
 		try {
 			PreparedStatement ps = getQuadStoreConnection().prepareStatement(query);
@@ -1567,7 +1563,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	 */
 	public void clearNamespaces() throws RepositoryException {
 		verifyIsOpen();
-		sendDelayAdd();
+		flushDelayAdd();
 		String query = "DB.DBA.XML_CLEAR_ALL_NS_DECLS()";
 		try {
 			java.sql.Statement stmt = getQuadStoreConnection().createStatement();
@@ -1579,15 +1575,15 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	}
 
 
-	protected TupleQueryResult executeSPARQLForTupleResult(String query, Dataset dataset) throws QueryEvaluationException {
+	protected TupleQueryResult executeSPARQLForTupleResult(String query, Dataset dataset, boolean includeInferred, BindingSet bindings) throws QueryEvaluationException {
 
 		Vector<String> names = new Vector<String>();
 		try {
 			verifyIsOpen();
-			sendDelayAdd();
+			flushDelayAdd();
 			java.sql.Statement stmt = getQuadStoreConnection().createStatement();
 			stmt.setFetchSize(prefetchSize);
-			ResultSet rs = stmt.executeQuery(fixQuery(query, dataset));
+			ResultSet rs = stmt.executeQuery(fixQuery(query, dataset, includeInferred, bindings));
 
 			ResultSetMetaData rsmd = rs.getMetaData();
 
@@ -1601,20 +1597,20 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 			return new TupleQueryResultImpl(names, new CloseableIterationBindingSet(rs));
 		}
 		catch (Exception e) {
-			throw new QueryEvaluationException(e);
+			throw new QueryEvaluationException(": SPARQL execute failed:["+query+"] \n Exception:"+e);
 		}
 	}
 	
-	protected GraphQueryResult executeSPARQLForGraphResult(String query, Dataset dataset) throws QueryEvaluationException {
+	protected GraphQueryResult executeSPARQLForGraphResult(String query, Dataset dataset, boolean includeInferred, BindingSet bindings) throws QueryEvaluationException {
 
 		HashMap<String,Integer> names = new HashMap<String,Integer>();
 
 		try {
 			verifyIsOpen();
-			sendDelayAdd();
+			flushDelayAdd();
 			java.sql.Statement stmt = getQuadStoreConnection().createStatement();
 			stmt.setFetchSize(prefetchSize);
-			ResultSet rs = stmt.executeQuery(fixQuery(query, dataset));
+			ResultSet rs = stmt.executeQuery(fixQuery(query, dataset, includeInferred, bindings));
 
 			ResultSetMetaData rsmd = rs.getMetaData();
 
@@ -1624,20 +1620,18 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 			return new GraphQueryResultImpl(new HashMap<String,String>(), new CloseableIterationGraphResult(rs));
 		}
 		catch (Exception e) {
-			throw new QueryEvaluationException(e);
+			throw new QueryEvaluationException(": SPARQL execute failed:["+query+"] \n Exception:"+e);
 		}
 		
 	}
 
-	protected boolean executeSPARQLForBooleanResult(String query, Dataset dataset) throws QueryEvaluationException {
-		Vector<String> names = new Vector<String>();
-		Vector<BindingSet> bindings = new Vector<BindingSet>();
+	protected boolean executeSPARQLForBooleanResult(String query, Dataset dataset, boolean includeInferred, BindingSet bindings) throws QueryEvaluationException {
 		boolean result = false;
 		try {
 			verifyIsOpen();
-			sendDelayAdd();
+			flushDelayAdd();
 			java.sql.Statement stmt = getQuadStoreConnection().createStatement();
-			ResultSet rs = stmt.executeQuery(fixQuery(query, dataset));
+			ResultSet rs = stmt.executeQuery(fixQuery(query, dataset, includeInferred, bindings));
 
 			while(rs.next())
 			{
@@ -1649,19 +1643,19 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 			return result;
 		}
 		catch (Exception e) {
-			throw new QueryEvaluationException(e);
+			throw new QueryEvaluationException(": SPARQL execute failed:["+query+"] \n Exception:"+e);
 		}
 	}
 
 
-	protected void executeSPARQLForHandler(TupleQueryResultHandler tqrh, String query, Dataset dataset) throws QueryEvaluationException, TupleQueryResultHandlerException {
+	protected void executeSPARQLForHandler(TupleQueryResultHandler tqrh, String query, Dataset dataset, boolean includeInferred, BindingSet bindings) throws QueryEvaluationException, TupleQueryResultHandlerException {
 		LinkedList<String> names = new LinkedList<String>();
 		try {
 			verifyIsOpen();
-			sendDelayAdd();
+			flushDelayAdd();
 			java.sql.Statement stmt = getQuadStoreConnection().createStatement();
 			stmt.setFetchSize(prefetchSize);
-			ResultSet rs = stmt.executeQuery(fixQuery(query, dataset));
+			ResultSet rs = stmt.executeQuery(fixQuery(query, dataset, includeInferred, bindings));
 
 			ResultSetMetaData rsmd = rs.getMetaData();
 			// begin at onset one
@@ -1685,18 +1679,18 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
                         stmt.close();
 		}
 		catch (Exception e) {
-			throw new QueryEvaluationException(e);
+			throw new QueryEvaluationException(": SPARQL execute failed:["+query+"] \n Exception:"+e);
 		}
 	}
 
 
-	protected void executeSPARQLForHandler(RDFHandler tqrh, String query, Dataset dataset) throws QueryEvaluationException, RDFHandlerException {
+	protected void executeSPARQLForHandler(RDFHandler tqrh, String query, Dataset dataset, boolean includeInferred, BindingSet bindings) throws QueryEvaluationException, RDFHandlerException {
 		try {
 			verifyIsOpen();
-			sendDelayAdd();
+			flushDelayAdd();
 			java.sql.Statement stmt = getQuadStoreConnection().createStatement();
 			stmt.setFetchSize(prefetchSize);
-			ResultSet rs = stmt.executeQuery(fixQuery(query, dataset));
+			ResultSet rs = stmt.executeQuery(fixQuery(query, dataset, includeInferred, bindings));
 			ResultSetMetaData rsmd = rs.getMetaData();
 	                int col_g = -1;
         	        int col_s = -1;
@@ -1743,7 +1737,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 			stmt.close();
 		}
 		catch (Exception e) {
-			throw new QueryEvaluationException(e);
+			throw new QueryEvaluationException(": SPARQL execute failed:["+query+"] \n Exception:"+e);
 		}
 	}
 	
@@ -1761,13 +1755,13 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 
 		try {
 			verifyIsOpen();
-			sendDelayAdd();
+			flushDelayAdd();
 			java.sql.Statement stmt = getQuadStoreConnection().createStatement();
 			stmt.execute("sparql\n define output:format '_JAVA_'\n " + query);
 			return stmt.getUpdateCount();
 		}
 		catch (SQLException e) {
-			throw new RepositoryException(e);
+			throw new RepositoryException(": SPARQL execute failed:["+query+"] \n Exception:"+e);
 		}
 	}
 
@@ -1790,21 +1784,74 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 		this.quadStoreConnection = quadStoreConnection;
 	}
 
-	private String fixQuery(String query, Dataset dataset) {
+	private String substBindings(String query, BindingSet bindings) 
+	{
+		StringBuffer buf = new StringBuffer();
+		String delim = " ,)(;.";
+	  	int i = 0;
+	  	char ch;
+	  	int qlen = query.length();
+	  	while( i < qlen) {
+	    		ch = query.charAt(i++);
+	    		if (ch == '\\') {
+	    			buf.append(ch);
+	    			if (i < qlen)
+	    				buf.append(query.charAt(i++)); 
+
+	    		} else if (ch == '"' || ch == '\'') {
+	      			char end = ch;
+	      			buf.append(ch);
+	      			while (i < qlen) {
+	        			ch = query.charAt(i++);
+	        			buf.append(ch);
+	        			if (ch == end)
+	          				break;
+	      			}
+	    		} else  if ( ch == '?' ) {  //Parameter
+	      			String varData = null;
+	      			int j = i;
+	      			while(j < qlen && delim.indexOf(query.charAt(j)) < 0) j++;
+	      			if (j != i) {
+	        			String varName = query.substring(i, j);
+	        			Value val = bindings.getValue(varName);
+	        			if (val != null) {
+                  				varData = stringForValue(val);
+                  				i=j;
+                			}
+	      			}
+	      			if (varData != null)
+	        			buf.append(varData);
+	      			else
+	        			buf.append(ch);
+	    		} else {
+	      			buf.append(ch);
+	    		}
+	  	}
+		return buf.toString();
+	}
+	
+	private String fixQuery(String query, Dataset dataset, boolean includeInferred, BindingSet bindings) 
+	{
 		StringTokenizer tok = new StringTokenizer(query);
 		String s = "";
 
+/*****
 		while(tok.hasMoreTokens()) {
 		    s = tok.nextToken().toLowerCase();
-		    if (s.equals("describe") || s.equals("construct") || s.equals("ask")) 
+		    if (s.equals("describe") || s.equals("construct") || s.equals("ask") || s.equals("select")) 
 			break;
 		}
 
-		StringBuffer ret = new StringBuffer();
+		StringBuffer ret = new StringBuffer("sparql\n ");
 		if (s.equals("describe") || s.equals("construct") || s.equals("ask")) 
-			ret.append("sparql\n define output:format '_JAVA_'\n ");
-		else 
-			ret.append("sparql\n ");
+			ret.append("define output:format '_JAVA_'\n ");
+*******/
+		StringBuffer ret = new StringBuffer("sparql\n ");
+
+		if (includeInferred && repository.ruleSet!=null && repository.ruleSet.length() > 0)
+		  ret.append("define input:inference '"+repository.ruleSet+"'\n ");
+
+		ret.append("define output:format '_JAVA_'\n ");
 
 		if (dataset != null)
 		{
@@ -1830,7 +1877,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 		     }
 		   }
 		}
-		ret.append(query);
+		ret.append(substBindings(query, bindings));
 		return ret.toString();
 	}
 
@@ -1895,6 +1942,21 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 		}
 	}
 
+	private void flushDelayAdd() throws RepositoryException 
+	{
+		synchronized(this) {
+			try {
+				if (psInsertCount > 0 && psInsert!=null) {
+					psInsert.executeBatch();
+					psInsert.clearBatch();
+					psInsertCount = 0;
+				}
+			}
+			catch (Exception e) {
+			}
+		}
+	}
+
 	private void dropDelayAdd() throws RepositoryException 
 	{
 		synchronized(this) {
@@ -1926,7 +1988,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 
 	private CloseableIteration<Statement, RepositoryException> selectFromQuadStore(Resource subject, URI predicate, Value object, boolean includeInferred, boolean hasOnly, Resource... contexts) throws RepositoryException {
 		verifyIsOpen();
-		sendDelayAdd();
+		flushDelayAdd();
 
 		ResultSet rs = null;
 		String s = "?s";
@@ -1940,7 +2002,12 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 		if (object != null) 
 			o = stringForValue(object);
 
-		StringBuffer query = new StringBuffer("sparql select * ");
+		StringBuffer query = new StringBuffer("sparql ");
+
+		if (includeInferred && repository.ruleSet != null && repository.ruleSet.length() > 0)
+		  query.append("define input:inference '"+repository.ruleSet+"' ");
+
+		query.append("select * ");
 
 		for (int i = 0; i < contexts.length; i++) {
 
@@ -2086,6 +2153,20 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 	}
 	
 
+	private String escapeString(String s) {
+		StringBuffer buf = new StringBuffer(s.length());
+	  	int i = 0;
+	  	char ch;
+	  	while( i < s.length()) {
+	    		ch = s.charAt(i++);
+	    		if (ch == '\'') 
+				buf.append('\\');
+			buf.append(ch);
+	  	}
+		return buf.toString();
+	}
+
+
 	private String stringForResource(Resource n) {
 		if (n instanceof URI) 
 			return stringForURI((URI) n);
@@ -2111,14 +2192,14 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 			return stringForResource((Resource) n);
 		else if (n instanceof Literal) {
 			Literal lit = (Literal) n;
-			String o = "\"" + lit.stringValue() + "\"";
+			String o = "'" + escapeString(lit.stringValue()) + "'";
 			if (lit.getLanguage() != null) 
 				return o + "@" + lit.getLanguage();
 			else if (lit.getDatatype() != null) 
 				return o + "^^<" + lit.getDatatype() + ">";
 			return o;
 		}
-		else return "\"" + n.stringValue() + "\"";
+		else return "'" + escapeString(n.stringValue()) + "'";
 	}
 
 	
@@ -2128,7 +2209,7 @@ public class VirtuosoRepositoryConnection implements RepositoryConnection {
 		if (val instanceof ExtendedString) {
 			ExtendedString ves = (ExtendedString) val;
 			String valueString = ves.toString();
-			if (ves.getIriType() == ExtendedString.IRI) {
+			if (ves.getIriType() == ExtendedString.IRI && (ves.getStrType() & 0x01)==0x01) {
 				if (valueString.startsWith("_:")) {
 					valueString = valueString.substring(2);
 					return getRepository().getValueFactory().createBNode(valueString);
