@@ -1,7 +1,7 @@
 /*
  *  viwin32.c
  *
- *  $Id: viwin32.c,v 1.11.4.2 2011/10/26 09:30:03 source Exp $
+ *  $Id: viwin32.c,v 1.11 2009/04/14 11:53:45 source Exp $
  *
  *  OpenLink Virtuoso DBMS Server
  *  Main code for Win32
@@ -157,7 +157,7 @@ extern int ob_just_report;
 /*
  *  Globals for virtuoso
  */
-PCONFIG	pconfig = NULL;			/* configuration file */
+PCONFIG	pconfig;			/* configuration file */
 
 /*
  *  Module locals
@@ -1256,7 +1256,7 @@ usage (void)
       PACKAGE_VERSION, DBMS_SRV_GEN_MAJOR, DBMS_SRV_GEN_MINOR, build_thread_model, build_date);
   p = stpcpy (p, line);
 
-  sprintf (line, "Compiled for %s (%s)\n", build_opsys_id, build_host_id);
+  sprintf (line, "Compiled for 32 Bit Windows Operating Environments\n");
   p = stpcpy (p, line);
 
   if (build_special_server_model && strlen(build_special_server_model) > 1)
