@@ -1,7 +1,7 @@
 --
 --  vfs.sql
 --
---  $Id: vfs.sql,v 1.10.2.7 2010/01/28 14:09:56 source Exp $
+--  $Id: vfs.sql,v 1.10.2.13 2010/07/06 10:43:12 source Exp $
 --
 --  Site-copy robot.
 --  
@@ -236,7 +236,14 @@ get_again:
 	    }
 	  else if (_other = 'checked')
 	    {
-	      WS.WS.VFS_ENSURE_NEW_SITE (_host, _root, new_host, new_url);
+	      if (ext_hook is not null and __proc_exists (ext_hook))
+		{
+		  WS.WS.SITEMAP_ENSURE_NEW_SITE (_host, _root, new_host, new_url); 
+	        }
+	      else
+		{
+	          WS.WS.VFS_ENSURE_NEW_SITE (_host, _root, new_host, new_url);
+		}
 	      insert soft VFS_QUEUE (VQ_HOST, VQ_TS, VQ_URL, VQ_STAT, VQ_ROOT, VQ_OTHER, VQ_LEVEL)
 		  values (new_host, now (), new_url, 'waiting', new_host, 'other', lev + 1);
     }
@@ -323,6 +330,13 @@ do_again1:
 	}
       commit work;
     }
+  oq := (select DB.DBA.VECTOR_AGG (vector (HOST, ROOT)) from (select distinct VQ_HOST as HOST, VQ_ROOT as ROOT 
+  	from VFS_QUEUE where VQ_STAT = 'waiting' and VQ_OTHER = 'other') x);
+  if (length (oq) > 0)
+    {
+      commit work;
+      goto do_again1;
+    }    
   --dbg_obj_print ('COMPLETED WITH STATUS: ', _stat, ' ', _msg);
 }
 ;
@@ -373,7 +387,8 @@ create procedure WS.WS.SERV_QUEUE (in __tgt varchar, in __root varchar, in _upd
 	}
       else if (not exists (select 1 from VFS_QUEUE where VQ_HOST = _tgt and VQ_ROOT = _root and VQ_STAT = 'waiting'))
 	{
-	  update VFS_QUEUE set VQ_STAT = 'waiting' where VQ_HOST = _tgt and VQ_ROOT = _root;
+	  -- make only sitemaps (if any) waiting here, otherwise make all waiting  
+	  update VFS_QUEUE set VQ_STAT = 'waiting' where VQ_HOST = _tgt and VQ_ROOT = _root and VQ_VIA_SITEMAP = 0;
 	}
       commit work;
     }
@@ -856,9 +871,11 @@ not_ini:
 
   if (_img is not null and substring (http_mime_type (_t_url), 1, 6) = 'image/')
     return 1;
+  else if (0 = length (_nflw_s) and 0 = length (_img) and substring (http_mime_type (_t_url), 1, 6) = 'image/')
+    return 0;
 
   if (_flw_s is null or _flw_s = '')
-    _flw_s := concat (_url, '%');
+    _flw_s := '/%';
 
   if (_nflw_s is null or _nflw_s = '')
     _nflw_s := ('');
@@ -1726,32 +1743,78 @@ create procedure WS.WS.SITEMAP_ENSURE_NEW_SITE (in _host varchar, in _root varch
 {
   if (not exists (select 1 from WS.WS.VFS_SITE where VS_HOST = _new_host and VS_ROOT = _root))
     {    
-      insert into WS.WS.VFS_SITE (VS_HOST, VS_ROOT, VS_URL, VS_SRC, VS_OWN, VS_DEL, VS_NEWER, VS_FOLLOW, VS_NFOLLOW, VS_METHOD, VS_OTHER, VS_DESCR)
-	  select _new_host, _root, _new_url, VS_SRC, VS_OWN, VS_DEL, VS_NEWER, VS_FOLLOW, VS_NFOLLOW, VS_METHOD, VS_OTHER, VS_DESCR ||':'|| _new_host 
+      insert into WS.WS.VFS_SITE (VS_HOST, VS_ROOT, VS_URL, VS_SRC, VS_OWN, VS_DEL, VS_NEWER, VS_FOLLOW, VS_NFOLLOW, VS_METHOD, VS_OTHER, VS_DESCR, 
+	  	VS_EXTRACT_FN, VS_STORE_FN, VS_DEPTH, VS_STORE, VS_DLOAD_META, VS_UDATA)
+	  select _new_host, _root, _new_url, VS_SRC, VS_OWN, VS_DEL, VS_NEWER, VS_FOLLOW, VS_NFOLLOW, VS_METHOD, VS_OTHER, VS_DESCR ||':'|| _new_host,
+		VS_EXTRACT_FN, VS_STORE_FN, VS_DEPTH, VS_STORE, VS_DLOAD_META, VS_UDATA 
 	  from WS.WS.VFS_SITE where VS_HOST = _host and VS_ROOT = _root;
     }    
 }
 ;
 
 
-create procedure WS.WS.SITEMAP_URLS_REGISTER (in _host varchar, in _root varchar, inout xp any, in lev int := 0)
+create procedure WS.WS.SITEMAP_URLS_REGISTER (in _host varchar, in _root varchar, inout xp any, in lev int := 0, in sm int := 0)
 {
   foreach (any u in xp) do
     {
       declare hf, host, url varchar;
+      declare ts datetime;
 
+      ts := null;
+      if (isvector (u))
+	{
+	  ts := u[1];
+	  if (ts is null) ts := now ();
+	  u :=  cast (u[0] as varchar);
+	}
+      else
       u := cast (u as varchar);
       hf := WS.WS.PARSE_URI (u);
       host := hf[1];
-      url := hf[2];
-      WS.WS.SITEMAP_ENSURE_NEW_SITE (_host, _root, host, url);
-      insert soft WS.WS.VFS_QUEUE (VQ_HOST, VQ_TS, VQ_URL, VQ_STAT, VQ_ROOT, VQ_OTHER, VQ_LEVEL) 
-	  values (host, now (), url, 'waiting', _root, 'other', lev); 
+      hf [0] := '';
+      hf [1] := '';
+      hf [5] := ''; 
+      url := WS.WS.VFS_URI_COMPOSE (hf);
+      if (WS.WS.FOLLOW (_host, _root, url))
+	{
+	  WS.WS.SITEMAP_ENSURE_NEW_SITE (_host, _root, host, url);
+	  if (not exists (select 1 from WS.WS.VFS_QUEUE where VQ_HOST = host and VQ_ROOT = _root and VQ_URL = url))
+	    {
+	      insert soft WS.WS.VFS_QUEUE (VQ_HOST, VQ_TS, VQ_URL, VQ_STAT, VQ_ROOT, VQ_OTHER, VQ_LEVEL, VQ_VIA_SITEMAP) 
+		  values (host, now (), url, 'waiting', _root, 'other', lev, sm); 
+	    }
+	  else
+	    {
+	      update WS.WS.VFS_QUEUE set VQ_STAT = 'waiting' where VQ_HOST = host and VQ_ROOT = _root and VQ_URL = url and VQ_TS < ts;
+	    }
+	}
     }
   commit work;
 }
 ;
 
+create procedure WS.WS.SITEMAP_GET_LOC (inout xt any, in qr varchar, in loc varchar, in ts varchar)
+{
+  declare xp, res any;
+  declare i int;
+
+  xp := xpath_eval (qr, xt, 0);
+  res := make_array (length (xp), 'any');
+  i := 0;
+  foreach (any x in xp) do
+    {
+      declare l, t any;
+      l := cast (xpath_eval (loc, x) as varchar);
+      t := xpath_eval (ts, x);
+      if (t is not null)
+	t := cast (cast (t as varchar) as datetime);
+      res[i] := vector (l, t);	
+      i := i + 1;
+    }
+  return res;
+}
+;
+
 create procedure WS.WS.SITEMAP_XML_PARSE (in _host varchar, in _url varchar, in _root varchar, inout _content varchar, 
 	in _c_type varchar := null, in lev int := 0)
 {
@@ -1766,28 +1829,51 @@ create procedure WS.WS.SITEMAP_XML_PARSE (in _host varchar, in _url varchar, in
     {
       _content := gzip_uncompress (_content); 
     }
-  if (_url like '%.xml' or _url like '%.xml.gz')
+  if (_url like '%.xml' or _url like '%.xml.gz' or _c_type = 'text/xml' or _c_type = 'application/xml' or _c_type = 'application/sparql-results+xml')
     {
       xt := xtree_doc (_content);
       if (xpath_eval ('/urlset/dataset', xt) is not null)
 	{
+	  declare ts any;
 	  xp := xpath_eval ('/urlset/dataset/dataDumpLocation/text()', xt, 0);
-	  WS.WS.SITEMAP_URLS_REGISTER (_host, _root, xp, lev);
+	  ts := xpath_eval ('/urlset/dataset/lastmod/text()', xt);
+	  if (ts is not null)
+	    {
+	      declare ar any;
+	      declare i int;
+	      i := 0;
+	      ts := cast (cast (ts as varchar) as datetime);
+	      ar := make_array (length (xp), 'any');
+	      foreach (any x in xp) do
+		{
+		  ar[i] := vector (cast (x as varchar), ts);
+		  i := i + 1;
+		}
+	      xp := ar;
+	    }
+	  WS.WS.SITEMAP_URLS_REGISTER (_host, _root, xp, lev, 0);
 	}
       else if (xpath_eval ('/sitemapindex/sitemap/loc', xt) is not null)
 	{
-	  xp := xpath_eval ('/sitemapindex/sitemap/loc/text()', xt, 0);
-	  WS.WS.SITEMAP_URLS_REGISTER (_host, _root, xp, lev);
+	  --xp := xpath_eval ('/sitemapindex/sitemap/loc/text()', xt, 0);
+	  xp := WS.WS.SITEMAP_GET_LOC (xt, '/sitemapindex/sitemap', './loc/text()', './lastmod/text()');
+	  WS.WS.SITEMAP_URLS_REGISTER (_host, _root, xp, lev, 0);
 	}
       else if (_c_type = 'application/sparql-results+xml')
 	{
 	  xp := xpath_eval ('/sparql/results/result/binding/uri/text()', xt, 0);
-	  WS.WS.SITEMAP_URLS_REGISTER (_host, _root, xp, lev);
+	  WS.WS.SITEMAP_URLS_REGISTER (_host, _root, xp, lev, 0);
+	}
+      else if (xpath_eval ('/urlset/url/loc', xt) is not null)
+	{
+	  --xp := xpath_eval ('/urlset/url/loc/text()', xt, 0);
+	  xp := WS.WS.SITEMAP_GET_LOC (xt, '/urlset/url', './loc/text()', './lastmod/text()');
+	  WS.WS.SITEMAP_URLS_REGISTER (_host, _root, xp, lev, 1);
 	}
       if (xpath_eval ('/urlset/dataset/sampleURI', xt) is not null)
 	{
 	  xp := xpath_eval ('/urlset/dataset/sampleURI/text()', xt, 0);
-	  WS.WS.SITEMAP_URLS_REGISTER (_host, _root, xp, lev);
+	  WS.WS.SITEMAP_URLS_REGISTER (_host, _root, xp, lev, 1);
 	}
     }
 }
@@ -1797,7 +1883,7 @@ create procedure WS.WS.SITEMAP_RDF_STORE (in _host varchar, in _url varchar, in
                               inout _content varchar, in _s_etag varchar, in _c_type varchar,
 			      in store_flag int := 1, in udata any := null, in lev int := 0)
 {
-  declare graph varchar;
+  declare graph, url_ck, base varchar;
   graph := null;
   declare exit handler for sqlstate '*'
     {
@@ -1808,15 +1894,34 @@ create procedure WS.WS.SITEMAP_RDF_STORE (in _host varchar, in _url varchar, in
       return;
     };
 
-  graph := WS.WS.VFS_URI_COMPOSE (vector ('http', _host, _url, '', '', ''));
-
-  if (_url like '%.rdf' or _c_type = 'application/rdf+xml')
+  if (isvector (udata) and isstring (get_keyword ('rdf-graph', udata)))
+    graph := get_keyword ('rdf-graph', udata, '');
+  base := WS.WS.VFS_URI_COMPOSE (vector ('http', _host, _url, '', '', ''));
+  if (not length (graph))  
+    graph := base;
+  url_ck := _url;
+  if (_url like '%.gz')
     {
-      DB.DBA.RDF_LOAD_RDFXML (_content, graph, graph);
+      if (length (_content) > 2)
+	{
+	  declare magic varchar;
+	  magic := subseq (_content, 0, 2);
+	  if (magic[0] = 0hex1f and magic[1] = 0hex8b) 
+      _content := gzip_uncompress (_content);
+	}
+      url_ck := regexp_replace (_url, '\.gz\x24', '');  
     }
-  else if (_url like '%.n3' or _url like '%.ttl' or _url like '%.nt' or _c_type = 'text/n3' or _c_type = 'text/rdf+n3')
+  if (url_ck like '%.rdf' or _c_type = 'application/rdf+xml')
     {
-      DB.DBA.TTLP (_content, graph, graph, 255);
+      DB.DBA.RDF_LOAD_RDFXML (_content, base, graph, 3);
+    }
+  else if (url_ck like '%.n3' or url_ck like '%.ttl' or url_ck like '%.nt' or _c_type = 'text/n3' or _c_type = 'text/rdf+n3')
+    {
+      DB.DBA.TTLP (_content, base, graph, 255, 3);
+    }
+  else if (_c_type = 'text/html')
+    {
+      DB.DBA.RDF_LOAD_RDFA (_content, base, graph, 2);
     }
   if (isvector (udata) and isvector (get_keyword ('follow-property', udata)))
     {
@@ -1828,8 +1933,15 @@ create procedure WS.WS.SITEMAP_RDF_STORE (in _host varchar, in _url varchar, in
             arr[i] := iri_to_id (arr[i], 0);  
 	}
       objs := (select DB.DBA.VECTOR_AGG (id_to_iri (O)) from DB.DBA.RDF_QUAD where G = iri_to_id (graph, 0) and P in (arr) and isiri_id (O));
-      WS.WS.SITEMAP_URLS_REGISTER (_host, _root, objs, lev);
+      WS.WS.SITEMAP_URLS_REGISTER (_host, _root, objs, lev, 0);
     } 
+  if (_c_type = 'text/html' and isvector (udata) and 1 = get_keyword ('follow-meta', udata, 0))
+    {
+      declare xt, xp any;
+      xt := xtree_doc (_content, 2);
+      xp := xpath_eval ('/html/head/link[@rel="meta"]/@href', xt, 0);
+      WS.WS.SITEMAP_URLS_REGISTER (_host, _root, xp, lev, 0);
+    }
   insert soft WS.WS.VFS_URL (VU_HOST, VU_URL, VU_CHKSUM, VU_CPTIME, VU_ETAG, VU_ROOT)
       values (_host, _url, md5 (_content), now (), _s_etag, _root);
   if (row_count () = 0)
