@@ -1,5 +1,5 @@
 /*
- *  $Id: VirtuosoConnection.java,v 1.9.2.7 2009/12/23 16:15:53 source Exp $
+ *  $Id: VirtuosoConnection.java,v 1.9.2.11 2010/07/09 14:22:28 source Exp $
  *
  *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
  *  project.
@@ -164,8 +164,12 @@ public class VirtuosoConnection implements Connection
 
   private Vector hostList = new Vector();
 #endif
+   protected boolean rdf_type_loaded = false;
+   protected boolean rdf_lang_loaded = false;
 
   private boolean useRoundRobin;
+  // The pingStatement to know if the connection is still available
+  private PreparedStatement pingStatement = null;
 
 
    protected class VhostRec
@@ -291,17 +295,23 @@ public class VirtuosoConnection implements Connection
       if(user == null || user.equals(""))
          user = "anonymous";
       password = (String)prop.get("password");
-      if(password == null)
+      if (password == null)
          password = "";
-      if(prop.get("timeout") != null)
-		   timeout = Integer.parseInt(prop.getProperty("timeout"));
+      if (prop.get("timeout") != null)
+	 timeout = Integer.parseInt(prop.getProperty("timeout"));
       pwdclear = (String)prop.get("pwdclear");
       if(prop.get("sendbs") != null)
-		   sendbs = Integer.parseInt(prop.getProperty("sendbs"));
+	  sendbs = Integer.parseInt(prop.getProperty("sendbs"));
+      if (sendbs <= 0)
+          sendbs = 32768;
       if(prop.get("recvbs") != null)
-		   recvbs = Integer.parseInt(prop.getProperty("recvbs"));
-      if(prop.get("fbs") != null)
-		   fbs = Integer.parseInt(prop.getProperty("fbs"));
+          recvbs = Integer.parseInt(prop.getProperty("recvbs"));
+      if (recvbs <= 0)
+          recvbs = 32768;
+      if (prop.get("fbs") != null)
+          fbs = Integer.parseInt(prop.getProperty("fbs"));
+      if (fbs <= 0)
+          fbs = VirtuosoTypes.DEFAULTPREFETCH;;
       //System.err.println ("3PwdClear is " + pwdclear);
 #ifdef SSL
       keystore_cert = (String)prop.get("certificate");
@@ -341,6 +351,18 @@ public class VirtuosoConnection implements Connection
 
       // Connect to the database
       connect(host,port,(String)prop.get("database"), sendbs, recvbs, (prop.get("log_enable") != null ? (Integer.parseInt(prop.getProperty("log_enable"))) : -1));
+
+      pingStatement = prepareStatement("select 1");
+   }
+
+   public boolean isConnectionLost() 
+   {
+     try{
+        pingStatement.execute();
+        return false;
+     } catch (Exception e ) {
+        return true;
+     } 
    }
 
    protected int getIntAttr(java.util.Properties info, String key, int def)
@@ -823,6 +845,15 @@ public class VirtuosoConnection implements Connection
      return fut;
    }
 
+   protected void clearFutures() 
+   {
+     if (futures != null) 
+        synchronized (futures)
+        {
+	  futures.clear();
+        }
+   }
+
    /**
     * Remove a future from the hashtable.
     *
