@@ -1,5 +1,5 @@
 /*
- *  $Id: VirtuosoPooledConnection.java,v 1.2.2.3 2009/10/16 15:08:42 source Exp $
+ *  $Id: VirtuosoPooledConnection.java,v 1.2.2.5 2010/03/26 19:48:27 source Exp $
  *
  *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
  *  project.
@@ -132,6 +132,7 @@ public class VirtuosoPooledConnection implements PooledConnection, Cloneable {
     pconn.tmClosed = System.currentTimeMillis();
     pconn.pStmtsPool = StmtsPool;
     pconn.conn.pooled_connection = pconn;
+    pconn.conn.clearFutures();
     return pconn;
   }
 
@@ -260,6 +261,14 @@ public class VirtuosoPooledConnection implements PooledConnection, Cloneable {
     return conn;
   }
 
+  public boolean isConnectionLost()
+  {
+    if (conn == null) {
+       return true;
+    }
+    return conn.isConnectionLost();
+  }
+
 #if JDK_VER >= 16
 	/**
 	 * Registers a <code>StatementEventListener</code> with this <code>PooledConnection</code> object.  Components that
