@@ -1,5 +1,5 @@
 /*
- *  $Id: VirtuosoStatement.java,v 1.5.2.3 2009/08/21 11:36:14 source Exp $
+ *  $Id: VirtuosoStatement.java,v 1.5.2.4 2010/03/18 10:20:07 source Exp $
  *
  *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
  *  project.
@@ -724,7 +724,8 @@ public class VirtuosoStatement implements Statement
    {
       if(rows < 0 || (maxRows > 0 && rows > maxRows))
          throw new VirtuosoException("Bad parameters.",VirtuosoException.BADPARAM);
-      prefetch = rows;
+	
+      prefetch = (rows == 0 ? VirtuosoTypes.DEFAULTPREFETCH : rows);
    }
 
    /**
