@@ -1,7 +1,7 @@
 /*
  *  bif_crypto.c
  *
- *  $Id: bif_crypto.c,v 1.10.2.1 2010/08/30 12:21:53 source Exp $
+ *  $Id: bif_crypto.c,v 1.8.2.2 2009/08/19 07:29:52 source Exp $
  *
  *  Cryptography functions
  *
@@ -137,7 +137,6 @@ DO_BIF_TREE_ALG(A_TYPE,A_NAME,A_PREFIX,A_LENGTH)
 DO_ALG (SHA, sha1, SHA1_, SHA_DIGEST_LENGTH)
 DO_BOX_ALG_1 (HMAC, hmac, HMAC_)
 
-
 caddr_t
 get_ssl_error_text (char *buf, int len)
 {
@@ -795,7 +794,6 @@ virt_pem_password_cb (char *buf, int size, int rwflag, void *userdata)
     }
 }
 
-
 static EVP_PKEY *
 x509_get_pkey_from_buffer (caddr_t buffer, caddr_t password)
 {
@@ -1074,10 +1072,8 @@ err_ret:
 
 }
 
-
 #define VIRT_CERT_EXT "2.16.840.1.1113.1"
 
-
 static caddr_t
 BN_box (BIGNUM * x)
 {
@@ -1108,7 +1104,6 @@ bif_get_certificate_info (caddr_t * qst, caddr_t * err_ret, state_slot_t ** args
   long type = bif_long_arg (qst, args, 0, "get_certificate_info");
   caddr_t scert = BOX_ELEMENTS (args) > 1 ? bif_string_or_null_arg (qst, args, 1, "get_certificate_info") : NULL;
   int internal = 0;
-  char buffer[4096];
 
   if (qi->qi_client->cli_ws)
     ssl = (SSL *) tcpses_get_ssl (qi->qi_client->cli_ws->ws_session->dks_session);
@@ -1178,6 +1173,7 @@ bif_get_certificate_info (caddr_t * qst, caddr_t * err_ret, state_slot_t ** args
 	X509_NAME *subj = X509_get_subject_name (cert);
 	if (subj)
 	  {
+	    char buffer[4096];
 	    X509_NAME_oneline (subj, buffer, sizeof (buffer));
 	    ret = box_dv_short_string (buffer);
 	    break;
@@ -1189,6 +1185,7 @@ bif_get_certificate_info (caddr_t * qst, caddr_t * err_ret, state_slot_t ** args
 	X509_NAME *subj = X509_get_issuer_name (cert);
 	if (subj)
 	  {
+	    char buffer[4096];
 	    X509_NAME_oneline (subj, buffer, sizeof (buffer));
 	    ret = box_dv_short_string (buffer);
 	    break;
@@ -1316,43 +1313,6 @@ bif_get_certificate_info (caddr_t * qst, caddr_t * err_ret, state_slot_t ** args
 	  *err_ret = srv_make_new_error ("42000", "XXXXX", "Can not read the public key from the certificate");
 	break;
       }
-    case 10:
-      {
-	char *attr = BOX_ELEMENTS (args) > 4 ? bif_string_arg (qst, args, 4, "get_certificate_info") : "CN";
-	X509_NAME *subj = X509_get_subject_name (cert);
-	X509_NAME_ENTRY *ne, *ne_ret = NULL;
-	int n, i, len;
-	char *s, *data_ptr;
-	BIO *mem = BIO_new (BIO_s_mem ());
-	for (i = 0; NULL != subj && i < sk_X509_NAME_ENTRY_num(subj->entries); i++)
-	  {
-	    ne = sk_X509_NAME_ENTRY_value(subj->entries,i);
-	    n = OBJ_obj2nid (ne->object);
-	    if ((n == NID_undef) || ((s = OBJ_nid2sn (n)) == NULL))
-	      {
-		i2t_ASN1_OBJECT (buffer, sizeof (buffer), ne->object);
-		s = buffer;
-	      }
-	    if (!strcmp (s, attr))
-	      {
-		ne_ret = ne;
-		break;
-	      }
-	  }
-	if (ne_ret)
-	  {
-	    ASN1_STRING_print (mem, ne_ret->value);
-	    len = BIO_get_mem_data (mem, &data_ptr);
-	    if (len > 0 && data_ptr)
-	      {
-		ret = dk_alloc_box (len + 1, DV_SHORT_STRING);
-		memcpy (ret, data_ptr, len);
-		ret[len] = 0;
-	      }
-	  }
-	BIO_free (mem);
-	break;
-      }
     default:
       {
 	if (!internal)
@@ -1383,7 +1343,6 @@ bif_bin2hex (caddr_t * qst, caddr_t * err_ret, state_slot_t ** args)
   return out;
 }
 
-
 static caddr_t
 bif_sha1_digest (caddr_t * qst, caddr_t * err_ret, state_slot_t ** args)
 {
@@ -1400,7 +1359,6 @@ bif_sha1_digest (caddr_t * qst, caddr_t * err_ret, state_slot_t ** args)
   return box_dv_short_string ((char *) md64);
 }
 
-
 void
 bif_crypto_init (void)
 {
@@ -1442,3 +1400,4 @@ bif_crypto_init (void)
   bif_define_typed ("get_certificate_info", bif_get_certificate_info, &bt_any);
 }
 #endif
+
