@@ -1,7 +1,7 @@
 /*
  *  extent.c
  *
- *  $Id: extent.c,v 1.1.2.7 2009/10/15 07:38:32 source Exp $
+ *  $Id: extent.c,v 1.1.2.11 2010/06/09 12:30:04 source Exp $
  *
  *  Disk extent management
  *
@@ -63,6 +63,7 @@ extent_t * em_new_extent (extent_map_t * em, int type, dp_addr_t extends);
 dp_addr_t em_try_get_dp (extent_map_t * em, int pg_type, dp_addr_t near);
 dp_addr_t em_new_dp_1 (extent_map_t * em, int ext_type, dp_addr_t near);
 
+extern int32 c_dense_page_allocation;
 
 int
 fd_extend (dbe_storage_t * dbs, int fd, int n_pages)
@@ -110,7 +111,7 @@ dbs_seg_extend (dbe_storage_t * dbs, int n)
 	  for (inx2 = 0; inx2 < inx; inx2++)
 	    {
 	      fd = dst_fd (ds->ds_stripes[inx2]);
-	      ftruncate (fd, org_sz);
+	      FTRUNCATE (fd, org_sz);
 	      dst_fd_done (ds->ds_stripes[inx2], fd);
 	    }
 	  return 0;
@@ -189,8 +190,29 @@ dbs_extent_allocated (dbe_storage_t * dbs, dp_addr_t n)
     }
 }
 
+int32
+em_free_count (extent_map_t * em, int type)
+{
+  int32 n = 0;
+  DO_EXT (ext, em)
+    {
+      if (type != EXT_TYPE (ext))
+	continue;
+      n += ext_free_count (ext);
+    }
+  END_DO_EXT;
+  return n;
+}
+
+#define EM_DEC_FREE(em, t) \
+{ \
+  if (EXT_INDEX == t) em->em_n_free_pages--; \
+  else if (EXT_BLOB == t) em->em_n_free_blob_pages--; \
+  else em->em_n_free_remap_pages--;		      \
+}
 
 extern long dbf_no_disk;
+int32 dbs_check_extent_free_pages = 0;
 
 int
 dbs_file_extend (dbe_storage_t * dbs, extent_t ** new_ext_ret, int is_in_sys_em)
@@ -198,6 +220,7 @@ dbs_file_extend (dbe_storage_t * dbs, extent_t ** new_ext_ret, int is_in_sys_em)
   extent_map_t * em;
   	  extent_t * new_ext = NULL;
   int n, n_allocated = 0;
+  int32 em_n_free;
   dp_addr_t ext_first = dbs->dbs_n_pages;
   ASSERT_IN_DBS (dbs);
   if (dbf_no_disk)
@@ -228,6 +251,16 @@ dbs_file_extend (dbe_storage_t * dbs, extent_t ** new_ext_ret, int is_in_sys_em)
   if (!is_in_sys_em)
     mutex_enter (em->em_mtx);
 
+  if (dbs_check_extent_free_pages)
+    {
+      em_n_free = em_free_count (em, EXT_INDEX);
+      if (em->em_n_free_pages != em_n_free)
+	{
+	  log_error ("The %s free pages incorrect %d != %d actually free", em->em_name, em->em_n_free_pages, em_n_free);
+	  em->em_n_free_pages = em_n_free;
+	}
+    }
+
   if (em->em_n_free_pages < 16)
     {
       /* extending and the system extent has little space.  Make this ext a system index ext.  If allocating some other ext, retry and take the next ext for that.  */
@@ -272,16 +305,19 @@ dbs_file_extend (dbe_storage_t * dbs, extent_t ** new_ext_ret, int is_in_sys_em)
       if (n_allocated)
 	dbs_page_allocated (dbs, ext_first);
       last->bd_page = last->bd_physical_page = em_try_get_dp (em, EXT_INDEX, DP_ANY);
+      if (last->bd_page) EM_DEC_FREE (em, EXT_INDEX);
 
       last = page_set_extend (dbs, &dbs->dbs_incbackup_set, 0, DPF_INCBACKUP_SET);
       page_set_checksum_init (last->bd_buffer + DP_DATA);
       last->bd_page = last->bd_physical_page = em_try_get_dp (em, EXT_INDEX, DP_ANY);
+      if (last->bd_page) EM_DEC_FREE (em, EXT_INDEX);
       dbs->dbs_n_pages_in_sets += BITS_ON_PAGE;
     }
   if (dbs->dbs_n_pages > dbs->dbs_n_pages_in_extent_set)
     {
       buffer_desc_t * last = page_set_extend (dbs, &dbs->dbs_extent_set, 0, DPF_EXTENT_SET);
       last->bd_page = last->bd_physical_page = em_try_get_dp (em, EXT_INDEX, DP_ANY);
+      if (last->bd_page) EM_DEC_FREE (em, EXT_INDEX);
       LONG_SET (last->bd_buffer + DP_DATA, 1); /* the newly made ext is the 1st of this page of the ext set, so set the bm 1st bit to 1 */
       page_set_checksum_init (last->bd_buffer + DP_DATA);
       dbs->dbs_n_pages_in_extent_set += EXTENT_SZ * BITS_ON_PAGE;
@@ -795,13 +831,6 @@ em_new_extent (extent_map_t * em, int type, dp_addr_t extends)
 }
 
 
-#define EM_DEC_FREE(em, t) \
-{ \
-  if (EXT_INDEX == t) em->em_n_free_pages--; \
-  else if (EXT_BLOB == t) em->em_n_free_blob_pages--; \
-  else em->em_n_free_remap_pages--;		      \
-}
-
 
 dp_addr_t
 em_new_dp_1 (extent_map_t * em, int ext_type, dp_addr_t near)
@@ -854,7 +883,7 @@ em_new_dp_1 (extent_map_t * em, int ext_type, dp_addr_t near)
 	  return dp;
 	}
     }
-  new_ext = em_new_extent (em, ext_type, near_ext ? near_ext->ext_dp : 0);
+  new_ext = em_new_extent (em, ext_type, near_ext ? near_ext->ext_dp : EXT_EXTENDS_NONE);
   if (!new_ext)
     {
       return 0;
@@ -1015,7 +1044,7 @@ em_new_dp (extent_map_t * em, int type, dp_addr_t near, int * hold)
   else if (EXT_BLOB == type)
     dp = em_new_blob (em, near);
   else
-    dp = em_new_dp_1 (em, type, near);
+    dp = em_new_dp_1 (em, type, c_dense_page_allocation ? DP_ANY : near);
   if (EXT_INDEX == type && em != em->em_dbs->dbs_extent_map)
     sethash (DP_ADDR2VOID(dp), em->em_uninitialized, (void*) 1);
   em_printf ((" alloc L=%d t=%d\n", dp, type));
@@ -1463,7 +1492,7 @@ void
 dbs_cpt_extents (dbe_storage_t * dbs, dk_set_t free_trees)
 {
   /* compact the extent maps.  Put them in the registry.
-  * Deled go first because drop-create-drop-create would otherwise leave the dropped state in effect.*/
+  * Deleted go first because drop-create-drop-create would otherwise leave the dropped state in effect.*/
   DO_SET (index_tree_t *, free_it, &free_trees)
     {
       if (free_it->it_extent_map != dbs->dbs_extent_map
