@@ -1,7 +1,7 @@
 /*
  *  lock.c
  *
- *  $Id: lock.c,v 1.20.2.13 2010/02/01 01:45:06 source Exp $
+ *  $Id: lock.c,v 1.20.2.17 2010/05/21 12:26:35 source Exp $
  *
  *  Locking concurrency control
  *
@@ -165,6 +165,10 @@ lt_free (lock_trx_t * lt)
 #endif
   hash_table_destroy (&lt->lt_lock);
   hash_table_free (lt->lt_rb_hash);
+#ifdef VIRTTP
+  dk_free_tree (lt->lt_2pc._2pc_xid);
+  dk_free_tree (lt->lt_2pc._2pc_log);
+#endif
   dk_free ((caddr_t) lt, sizeof (lock_trx_t));
 }
 
@@ -209,6 +213,10 @@ lt_clear (lock_trx_t * lt)
   LT_ERROR_DETAIL_SET (lt, NULL);
   if (lt->lt_wait_end)
     GPF_T1 ("lt going clear but somebody still waiting for its end");
+#ifdef VIRTTP
+  dk_free_tree (lt->lt_2pc._2pc_xid);
+  dk_free_tree (lt->lt_2pc._2pc_log);
+#endif
   memset (&lt->LT_DATA_AREA_FIRST, 0, sizeof (lock_trx_t) - (size_t) &((lock_trx_t*) 0)->LT_DATA_AREA_FIRST);
   LT_ENTER_SAVE (lt);
   LT_THREADS_REPORT (lt, "LT_CLEAR");
@@ -1276,7 +1284,7 @@ lock_wait (gen_lock_t * pl, it_cursor_t * it, buffer_desc_t * buf,
   if (it->itc_page != it->itc_pl->pl_page)
     GPF_T1 ("different itc_oage and pl_page in lock_wait");
   lt_add_pl (it->itc_ltrx, it->itc_pl, 0);
-  lt->lt_wait_since = approx_msec_real_time (); /* first set approx inside the mtxm, then get real time outsid of the mtx */
+  lt->lt_wait_since = approx_msec_real_time (); /* first set approx inside the mtxm, then get real time outside of the mtx */
   if (!pl->pl_waiting)
     {
       pl->pl_waiting = it;
@@ -1853,21 +1861,36 @@ unsigned long checkpointed_last_time = 0;
 #include <sys/resource.h>
 #endif
 
-
-int last_majflt;
+int last_majflt = 0;
+int32 swap_guard_on = 0;
+int process_is_swapping = 0;
 
 void
 the_grim_swap_guard ()
 {
 #ifdef HAVE_GETRUSAGE
   struct rusage ru;
-  if (wi_inst.wi_is_checkpoint_pending)
+  if (!swap_guard_on)
     return;
+  if (wi_inst.wi_is_checkpoint_pending)
   return;
   getrusage (RUSAGE_SELF, &ru);
+#ifdef GPF_ON_SWAPPING
   if (ru.ru_majflt - last_majflt > 300)
     GPF_T1 ("started swapping");
+#endif
+  if (virtuoso_server_initialized && ru.ru_majflt - last_majflt > 300)
+    {
+      if (!process_is_swapping)
+	log_error ("The process started swapping, all pending transactions will be killed");
+      process_is_swapping = 1;
+    }
+  else
+    {
+      if (process_is_swapping)
+	process_is_swapping = 0;
   last_majflt = ru.ru_majflt;
+    }
 #endif
 }
 
@@ -1877,6 +1900,31 @@ extern uint32 cl_last_wait_query;
 
 uint32 prev_reaper_time;
 
+void
+clear_old_root_images ()
+{
+  long now = approx_msec_real_time ();
+  mutex_enter (old_roots_mtx);
+  {
+    buffer_desc_t ** prev = &old_root_images;
+    buffer_desc_t * old_img = old_root_images;
+    while (old_img)
+      {
+	buffer_desc_t * next = old_img->bd_next;
+	if ((bp_ts_t)now - old_img->bd_timestamp > 30000)
+	  {
+	    *prev = old_img->bd_next;
+	    resource_store (PM_RC (old_img->bd_content_map->pm_size), (void*) old_img->bd_content_map);
+	    buffer_free (old_img);
+	  }
+	else
+	  prev = &old_img->bd_next;
+	old_img = next;
+      }
+  }
+  mutex_leave (old_roots_mtx);
+}
+
 void
 the_grim_lock_reaper (void)
 {
@@ -1902,13 +1950,16 @@ the_grim_lock_reaper (void)
       client_connection_t * cli = lt->lt_client;
       CHECK_DK_MEM_RESERVE (lt);
       if (lt->lt_started &&
-	  lt->lt_timeout &&
-	  now - lt->lt_started > lt->lt_timeout &&
+	  ( (lt->lt_timeout && now - lt->lt_started > lt->lt_timeout) || (process_is_swapping && LT_IS_RUNNING (lt)) ) &&
 	  lt->lt_status == LT_PENDING)
 	{
 	  lt->lt_error = LTE_TIMEOUT;
 	  dbg_printf (("  Trx %s timed out after %ld msec.\n",
 		       LT_NAME (lt), now - lt->lt_started));
+#ifndef NDEBUG
+	  if (process_is_swapping)
+	    ws_lt_trace (lt);
+#endif
 	  lt_kill_other_trx (lt, NULL, NULL, LT_KILL_ROLLBACK);
 	  LEAVE_TXN;
 	  goto kill_next_txn;
@@ -1994,26 +2045,7 @@ the_grim_lock_reaper (void)
 	  schedule_last_time = (unsigned long int) now;
 	}
     }
-
-  mutex_enter (old_roots_mtx);
-  {
-    buffer_desc_t ** prev = &old_root_images;
-    buffer_desc_t * old_img = old_root_images;
-    while (old_img)
-      {
-	buffer_desc_t * next = old_img->bd_next;
-	if ((bp_ts_t)now - old_img->bd_timestamp > 30000)
-	  {
-	    *prev = old_img->bd_next;
-	    resource_store (PM_RC (old_img->bd_content_map->pm_size), (void*) old_img->bd_content_map);
-	    buffer_free (old_img);
-	  }
-	else
-	  prev = &old_img->bd_next;
-	old_img = next;
-      }
-  }
-  mutex_leave (old_roots_mtx);
+  clear_old_root_images ();
   http_reaper ();
   if (cfg_thread_live_period)
     {
