@@ -1,7 +1,7 @@
 /*
  *  ltrx.h
  *
- *  $Id: ltrx.h,v 1.14.2.7 2009/10/15 07:38:32 source Exp $
+ *  $Id: ltrx.h,v 1.14.2.9 2010/03/07 08:20:46 source Exp $
  *
  *  Locking transaction structures
  *
@@ -188,7 +188,7 @@ typedef struct lock_trx_s
     thread_t *		lt_thr;
     dk_hash_t 		lt_lock;
 #define lt_has_locks(lt) ((lt)->lt_lock.ht_count)
-    /* all below members are concidered data area and cleared with memset in lt_cleare, saving individual ones as needed */
+    /* all below members are considered data area and cleared with memset in lt_cleare, saving individual ones as needed */
 #define LT_DATA_AREA_FIRST lt_waits_for
     dk_set_t		lt_waits_for;
     dk_set_t		lt_waiting_for_this;
@@ -242,6 +242,8 @@ typedef struct lock_trx_s
       caddr_t		_2pc_prepared;
       dk_set_t		_2pc_remotes;
       int		_2pc_invalid; /* is set if one of branches in unreachable  */
+      box_t             _2pc_xid;
+      char              _2pc_wait_commit;
     } lt_2pc;
 #endif
 
