@@ -1,7 +1,7 @@
 /*
  *  meta.c
  *
- *  $Id: meta.c,v 1.17.2.4 2010/02/01 12:53:43 source Exp $
+ *  $Id: meta.c,v 1.17.2.7 2010/04/23 20:03:56 source Exp $
  *
  *  META
  *
@@ -987,7 +987,7 @@ key_fill_part_cls (dbe_key_t * key)
 }
 
 
-void
+int
 dbe_key_layout_1 (dbe_key_t * key)
 {
   int kf_fill = IE_FIRST_KEY, rf_fill = 0, kv_fill = 0, kv_fill_key = 0;
@@ -1038,7 +1038,7 @@ dbe_key_layout_1 (dbe_key_t * key)
       if (!deps)
 	{
 	  log_info ("Key without parts %s.", key->key_name);
-	  return;
+	  return 0;
 	}
       deps = deps->next;
     }
@@ -1068,13 +1068,8 @@ dbe_key_layout_1 (dbe_key_t * key)
       key_null_area = kf_fill;
       kf_fill += ALIGN_8 (key_nullables) / 8;
     }
-#if defined(WORDS_BIGENDIAN) && defined(SOLARIS)
-  kf_fill = ALIGN_8 (kf_fill);
-  key->key_length_area[0] = kf_fill;
-#else
   kf_fill = ALIGN_2 (kf_fill);
   key->key_length_area[0] = ALIGN_2 (kf_fill);
-#endif
   kv_fill = 0;
   key_place_var (key, &kv_fill, &null_fill, &key_var, keys);
 #ifdef DEBUG
@@ -1094,11 +1089,7 @@ dbe_key_layout_1 (dbe_key_t * key)
 #ifdef DEBUG
   n_placed += dk_set_length (row_var);
 #endif
-#if defined(WORDS_BIGENDIAN) && defined(SOLARIS)
-  rf_fill = ALIGN_8 (kf_fill + kv_fill);
-#else
   rf_fill = ALIGN_2 (kf_fill + kv_fill);
-#endif
   key->key_row_compressed_start[0] = rf_fill;
   key_place_fixed (key, &rf_fill, &null_fill, &row_fixed, deps);
 #ifdef DEBUG
@@ -1129,6 +1120,7 @@ dbe_key_layout_1 (dbe_key_t * key)
   key_fill_part_cls (key);
   if (key->key_is_bitmap)
     dk_set_free (deps);
+  return 1;
 }
 
 
@@ -1213,6 +1205,9 @@ key_set_version (dbe_key_t * key)
   key->key_versions = kv;
   if (1 == key->key_version)
     kv[0] = key;
+
+  if (key->key_version >= KEY_MAX_VERSIONS || key->key_version <= 0)
+    GPF_T1("key_version outside of array");
   kv[key->key_version] = key;
   mutex_leave (mtx);
 }
@@ -1401,7 +1396,8 @@ dbe_key_layout (dbe_key_t * key, dbe_schema_t * sc)
     }
   END_DO_SET();
 
-  dbe_key_layout_1 (key);
+  if (!dbe_key_layout_1 (key)) /* incomplete key, should not continue */
+    return;
   dbe_key_compression (key);
   dbe_key_list_pref_compressible (key);
   if (KI_TEMP == key->key_id)
