@@ -1,7 +1,7 @@
 /*
  *  mtwrite.c
  *
- *  $Id: mtwrite.c,v 1.8.2.6 2009/08/19 07:29:53 source Exp $
+ *  $Id: mtwrite.c,v 1.8.2.8 2010/03/08 12:04:12 source Exp $
  *
  *  Manages buffer rings and paging to disk.
  *
@@ -88,7 +88,9 @@ buf_cancel_write (buffer_desc_t * buf)
    * Thus the bd_iq of an occupied buffer can be async reset by another thread. */
   io_queue_t * iq = buf->bd_iq;
   if (buf->bd_tree)
-    ASSERT_OUTSIDE_MAP (buf->bd_tree, buf->bd_page);
+    {
+      ASSERT_OUTSIDE_MAP (buf->bd_tree, buf->bd_page);
+    }
 
   /* Note that this can block waiting for IQ which is owned by another
   thread in iq_schedule. The thread in iq_schedule can block on this
@@ -175,9 +177,11 @@ iq_schedule (buffer_desc_t ** bufs, int n)
 	}
       LEAVE_IOQ (iq);
       if (n_added && !is_reads)
-	idbg_printf (("IQ %s %d %s added, %s.\n", IQ_NAME (iq),
+        {
+	  dbg_printf (("IQ %s %d %s added, %s.\n", IQ_NAME (iq),
 		      n_added, is_reads ? "reads" : "writes",
 		      was_empty ? "starting" : "running"));
+	}
       if (n_added && was_empty)
 	semaphore_leave (iq->iq_sem);
 
@@ -311,7 +315,7 @@ iq_write_merge (struct aiocb ** list, int n, char * temp)
 void
 iq_listio (struct aiocb ** list, int fill)
 {
-  /* like lio_listio with LIO_WAIT , but merges reads that are close enough together, only PAGE_SZ chunks donw  */
+  /* like lio_listio with LIO_WAIT , but merges reads that are close enough together, only PAGE_SZ chunks down  */
   char temp_space [(MAX_MERGE + 1) * PAGE_SZ];
   char * temp = ALIGN_8K (&temp_space[0]);
   int inx;
