@@ -1,5 +1,5 @@
 --
---  $Id: rdf_sponge.sql,v 1.5.2.21 2010/01/31 20:46:39 source Exp $
+--  $Id: rdf_sponge.sql,v 1.5.2.24 2010/05/11 16:53:34 source Exp $
 --
 --  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 --  project.
@@ -88,7 +88,8 @@ create function DB.DBA.RDF_GRAB_SINGLE (in val any, inout grabbed any, inout env
         'get:refresh', get_keyword_ucase ('get:refresh', env),
         'get:method', get_method,
         'get:destination', final_dest,
-        'get:group-destination', final_gdest
+        'get:group-destination', final_gdest,
+        'get:strategy', get_keyword_ucase ('get:strategy', env)
 	 );
       dict_put (grabbed, url, 1);
       call (get_keyword ('loader', env))(url, opts);
@@ -872,6 +873,7 @@ create function DB.DBA.RDF_SPONGE_GUESS_CONTENT_TYPE (in origin_uri varchar, in
       if (strstr (ret_content_type, 'application/rdf+xml') is not null)
         return 'application/rdf+xml';
       if (
+        strstr (ret_content_type, 'text/n3') is not null or
         strstr (ret_content_type, 'text/rdf+n3') is not null or
         strstr (ret_content_type, 'text/rdf+ttl') is not null or
         strstr (ret_content_type, 'text/rdf+turtle') is not null or
@@ -908,7 +910,11 @@ create function DB.DBA.RDF_SPONGE_GUESS_CONTENT_TYPE (in origin_uri varchar, in
           -- dbg_obj_princ ('l = ', l);
           if (("LEFT" (l, 7) = '@prefix') or ("LEFT" (l, 5) = '@base') or ("LEFT" (l, 8) = '@keyword'))
             return 'text/rdf+n3';
-          if ((("LEFT" (l, 1) = '<') or ("LEFT" (l, 1) = '[')) and ("RIGHT" (origin_uri, 4) in ('.ttl', '.TTL', '.n3', '.N3')))
+          if ((("LEFT" (l, 1) = '<') or ("LEFT" (l, 1) = '[')) and
+	      (
+	       "RIGHT" (origin_uri, 4) in ('.ttl', '.TTL') or
+	       "RIGHT" (origin_uri, 3) in ('.n3', '.N3', '.nt', '.NT')
+	      ))
             return 'text/rdf+n3';
           if (not ((l like '#%') or (l='')))
             return 'text/plain';
@@ -1075,7 +1081,7 @@ create procedure DB.DBA.RDF_LOAD_HTTP_RESPONSE (in graph_iri varchar, in new_ori
   declare rc any;
   declare aq, ps any;
   declare xd, xt any;
-  declare saved_log_mode integer;
+  declare saved_log_mode, only_rdfa integer;
   aq := null;
   ps := cfg_item_value (virtuoso_ini_path (), 'SPARQL', 'PingService');
   if (length (ps))
@@ -1088,6 +1094,10 @@ create procedure DB.DBA.RDF_LOAD_HTTP_RESPONSE (in graph_iri varchar, in new_ori
   -- dbg_obj_princ ('ret_content_type is ', ret_content_type);
   dest := get_keyword_ucase ('get:destination', options);
   groupdest := get_keyword_ucase ('get:group-destination', options);
+  if (get_keyword_ucase ('get:strategy', options, 'default') = 'rdfa-only')
+    only_rdfa := 1;
+  else
+    only_rdfa := 0;
   if (strstr (ret_content_type, 'application/sparql-results+xml') is not null)
     signal ('RDFXX', sprintf ('Unable to load RDF graph <%.500s> from <%.500s>: the sparql-results XML answer does not contain triples', graph_iri, new_origin_uri));
   if (strstr (ret_content_type, 'application/rdf+xml') is not null)
@@ -1103,7 +1113,7 @@ create procedure DB.DBA.RDF_LOAD_HTTP_RESPONSE (in graph_iri varchar, in new_ori
       DB.DBA.RDF_LOAD_RDFXML (ret_body, new_origin_uri, coalesce (dest, graph_iri));
       if (groupdest is not null)
         DB.DBA.RDF_LOAD_RDFXML (ret_body, new_origin_uri, groupdest);
-      if (__proc_exists ('DB.DBA.RDF_LOAD_POST_PROCESS')) -- optional step, by default skip
+      if (__proc_exists ('DB.DBA.RDF_LOAD_POST_PROCESS') and only_rdfa = 0) -- optional step, by default skip
 	call ('DB.DBA.RDF_LOAD_POST_PROCESS') (graph_iri, new_origin_uri, dest, ret_body, ret_content_type, options);
       log_enable (saved_log_mode, 1);
       if (aq is not null)
@@ -1112,6 +1122,7 @@ create procedure DB.DBA.RDF_LOAD_HTTP_RESPONSE (in graph_iri varchar, in new_ori
     }
   else if (
        strstr (ret_content_type, 'text/rdf+n3') is not null or
+       strstr (ret_content_type, 'text/n3') is not null or
        strstr (ret_content_type, 'text/rdf+ttl') is not null or
        strstr (ret_content_type, 'text/rdf+turtle') is not null or
        strstr (ret_content_type, 'text/turtle') is not null or
@@ -1124,16 +1135,28 @@ create procedure DB.DBA.RDF_LOAD_HTTP_RESPONSE (in graph_iri varchar, in new_ori
       log_enable (2, 1);
       --if (dest is null)
       --  DB.DBA.SPARUL_CLEAR (coalesce (dest, graph_iri), 1);
-      DB.DBA.TTLP (ret_body, new_origin_uri, coalesce (dest, graph_iri));
+      DB.DBA.TTLP (ret_body, new_origin_uri, coalesce (dest, graph_iri), 255);
       if (groupdest is not null)
         DB.DBA.TTLP (ret_body, new_origin_uri, groupdest);
-      if (__proc_exists ('DB.DBA.RDF_LOAD_POST_PROCESS')) -- optional step, by default skip
+      if (__proc_exists ('DB.DBA.RDF_LOAD_POST_PROCESS') and only_rdfa = 0) -- optional step, by default skip
 	call ('DB.DBA.RDF_LOAD_POST_PROCESS') (graph_iri, new_origin_uri, dest, ret_body, ret_content_type, options);
       log_enable (saved_log_mode, 1);
       if (aq is not null)
         aq_request (aq, 'DB.DBA.RDF_SW_PING', vector (ps, new_origin_uri));
       return 1;
     }
+  else if (only_rdfa = 1 and strstr (ret_content_type, 'text/html') is not null)
+    {
+      whenever sqlstate '*' goto load_grddl;
+      log_enable (2, 1);
+      DB.DBA.RDF_LOAD_RDFA (ret_body, new_origin_uri, coalesce (dest, graph_iri), 2);
+      if (groupdest is not null and groupdest <> coalesce (dest, graph_iri))
+	DB.DBA.RDF_LOAD_RDFA (ret_body, new_origin_uri, groupdest, 2);
+      log_enable (saved_log_mode, 1);
+      if (aq is not null)
+        aq_request (aq, 'DB.DBA.RDF_SW_PING', vector (ps, new_origin_uri));
+      return 1;
+    }
 
   --if (dest is null)
   --  {
@@ -1173,7 +1196,7 @@ load_grddl:;
           npars := 8;
           if (isarray (pcols))
 	    npars := length (pcols);
-	  --!!!TBD: Carefully check what happens when dest is NULL vs dest is nonNULL, then add support for groupdest.
+	  --!!!TBD: Carefully check what happens when dest is NULL vs dest is not NULL, then add support for groupdest.
           if (registry_get ('__sparql_mappers_debug') = '1')
             dbg_obj_prin1 ('Match ', RM_HOOK);
 	  new_opts := vector_concat (options, RM_OPTIONS, vector ('content-type', ret_content_type, 'charset', cset));
