@@ -1,7 +1,7 @@
 /*
  *  rdfxml_parser.c
  *
- *  $Id: rdfxml_parser.c,v 1.17.2.8 2009/10/07 11:09:00 source Exp $
+ *  $Id: rdfxml_parser.c,v 1.17.2.10 2010/06/22 15:50:49 source Exp $
  *
  *  RDF/XML parser
  *
@@ -1130,6 +1130,8 @@ next_token:
     }
   else
     expanded_token = box_dv_short_nchars (token_start, token_end-token_start);
+  if (NULL == expanded_token)
+    goto next_token; /* see above */
   expanded_token_not_saved = 1;
   if (NULL != values_ret)
     {
@@ -1435,7 +1437,7 @@ xp_rdfa_element (void *userdata, char * name, vxml_parser_attrdata_t *attrdata)
       if (!strcmp (local_name, "base"))
         {
           if (RDFA_IN_BASE & outer_place_bits)
-            xmlparser_logprintf (xp->xp_parser, XCFG_ERROR, 100, "Element \"base\" can not appear inside other \"base\" elelent");
+            xmlparser_logprintf (xp->xp_parser, XCFG_ERROR, 100, "Element \"base\" can not appear inside other \"base\" element");
           inner_place_bits |= RDFA_IN_BASE;
           need_rdfa_local = 1;
         }
@@ -1445,7 +1447,7 @@ xp_rdfa_element (void *userdata, char * name, vxml_parser_attrdata_t *attrdata)
       if (!strcmp (local_name, "head"))
         {
           if ((RDFA_IN_HEAD | RDFA_IN_BODY) & outer_place_bits)
-            xmlparser_logprintf (xp->xp_parser, XCFG_ERROR, 100, "Element \"head\" can not appear inside %s elelent", (RDFA_IN_HEAD & outer_place_bits) ? "other \"head\"" : "\"body\"");
+            xmlparser_logprintf (xp->xp_parser, XCFG_ERROR, 100, "Element \"head\" can not appear inside %s element", (RDFA_IN_HEAD & outer_place_bits) ? "other \"head\"" : "\"body\"");
           else
             inner_place_bits |= RDFA_IN_HEAD;
           need_rdfa_local = 1;
@@ -1453,7 +1455,7 @@ xp_rdfa_element (void *userdata, char * name, vxml_parser_attrdata_t *attrdata)
       else if (!strcmp (local_name, "body"))
         {
           if ((RDFA_IN_HEAD | RDFA_IN_BODY) & outer_place_bits)
-            xmlparser_logprintf (xp->xp_parser, XCFG_ERROR, 100, "Element \"body\" can not appear inside %s elelent", (RDFA_IN_BODY & outer_place_bits) ? "other \"body\"" : "\"head\"");
+            xmlparser_logprintf (xp->xp_parser, XCFG_ERROR, 100, "Element \"body\" can not appear inside %s element", (RDFA_IN_BODY & outer_place_bits) ? "other \"body\"" : "\"head\"");
           else
             inner_place_bits |= RDFA_IN_BODY;
           need_rdfa_local = 1;
@@ -1969,7 +1971,7 @@ xp_rdfa_comment (void *userdata, const char *text)
 void
 rdfxml_parse (query_instance_t * qi, caddr_t text, caddr_t *err_ret,
   int mode_bits, const char *source_name, caddr_t base_uri, caddr_t graph_uri,
-  ccaddr_t *cbk_names, caddr_t app_env,
+  ccaddr_t *cbk_names, caddr_t *app_env,
   const char *enc, lang_handler_t *lh
    /*, caddr_t dtd_config, dtd_t **ret_dtd,
    id_hash_t **ret_id_cache, xml_ns_2dict_t *ret_ns_2dict*/ )
