@@ -1,7 +1,7 @@
 /*
  *  rendezvous.c
  *
- *  $Id: rendezvous.c,v 1.5.2.1 2009/04/18 21:55:13 source Exp $
+ *  $Id: rendezvous.c,v 1.5.2.2 2010/02/10 16:03:28 source Exp $
  *
  *  Rendezvous registration for Virtuoso
  *
@@ -116,27 +116,27 @@ static rv_ctx *_rv = NULL;
  */
 static dsn_tag dsn_tags[] =
   {
-    { "Address",	DSN_INVALID },
-    { "Charset",	DSN_VALID },
-    { "Database",	DSN_VALID },
-    { "Daylight",	DSN_VALID },
+    { "Address",	DSN_INVALID, 	NULL },
+    { "Charset",	DSN_VALID, 	NULL },
+    { "Database",	DSN_VALID, 	NULL },
+    { "Daylight",	DSN_VALID, 	NULL },
     { "DB",		DSN_VALID,	"Database" },
-    { "Description",	DSN_INVALID },
-    { "Driver",		DSN_INVALID },
-    { "DSN",		DSN_INVALID },
-    { "Encrypt",	DSN_INVALID },
-    { "Host",		DSN_INVALID },
+    { "Description",	DSN_INVALID,	NULL },
+    { "Driver",		DSN_INVALID,	NULL },
+    { "DSN",		DSN_INVALID,	NULL },
+    { "Encrypt",	DSN_INVALID,	NULL },
+    { "Host",		DSN_INVALID,	NULL },
     { "LastUser",	DSN_VALID,	"UID" },
-    { "NoLoginBox",	DSN_VALID },
+    { "NoLoginBox",	DSN_VALID,	NULL },
     { "Password",	DSN_VALID,	"PWD" },
-    { "Persist",	DSN_VALID },
-    { "PWD",		DSN_VALID },
-    { "PWDClearText",	DSN_VALID },
-    { "UID",		DSN_VALID },
+    { "Persist",	DSN_VALID,	NULL },
+    { "PWD",		DSN_VALID,	NULL },
+    { "PWDClearText",	DSN_VALID,	NULL },
+    { "UID",		DSN_VALID,	NULL },
     { "User",		DSN_VALID,	"UID" },
     { "UserID",		DSN_VALID,	"UID" },
     { "UserName",	DSN_VALID,	"UID" },
-    { "ZeroConf",	DSN_INVALID },
+    { "ZeroConf",	DSN_INVALID,	NULL },
   };
 
 
