@@ -1,5 +1,5 @@
 /*
- *  $Id: sparql2sql.h,v 1.55.2.11 2010/02/02 14:20:01 source Exp $
+ *  $Id: sparql2sql.h,v 1.55.2.16 2010/03/24 01:03:30 source Exp $
  *
  *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
  *  project.
@@ -487,7 +487,7 @@ The function will substitute all selids and tabids of all graph patterns and tri
 substitute equiv indexes with indexes of cloned equivs (except SPART_BAD_EQUIV_IDX index that persists). */
 extern SPART *sparp_gp_full_clone (sparp_t *sparp, SPART *gp);
 
-/*! This makes a full clone of \c origs. As a result, triples and variables outside any GPs are copied, inside GPs thay're changed like in case of sparp_gp_full_clone. */
+/*! This makes a full clone of \c origs. As a result, triples and variables outside any GPs are copied, inside GPs they're changed like in case of sparp_gp_full_clone. */
 extern SPART **sparp_treelist_full_clone (sparp_t *sparp, SPART **origs);
 
 /*! This creates a full copy of \c orig subtree without cloning equivs.
@@ -557,8 +557,10 @@ Restrictions on variables of \c new_filters should be propagated across the tree
 This is faster than attach \c new_filters by a sequence of sparp_gp_attach_member() calls. */
 extern void sparp_gp_attach_many_filters (sparp_t *sparp, SPART *parent_gp, SPART **new_filters, int insert_before_idx, sparp_equiv_t ***touched_equivs_ptr);
 
+extern void sparp_gp_tighten_by_eq_replaced_filters (sparp_t *sparp, SPART *dest, SPART *orig, int remove_origin);
+
 /*! This makes the gp and all its sub-gps unusable and marks 'deprecated' all equivs that belong to these gps. */
-extern void sparp_gp_deprecate (sparp_t *sparp, SPART *parent_gp);
+extern void sparp_gp_deprecate (sparp_t *sparp, SPART *parent_gp, int suppress_eq_check);
 
 /*! This calls sparp_gp_deprecate() for all gps ofa subquery. */
 extern void sparp_req_top_deprecate (sparp_t *sparp, SPART *top);
@@ -619,6 +621,9 @@ extern void sparp_make_aliases (sparp_t *sparp);
 /*! Label variables as EXTERNAL. */
 extern void sparp_label_external_vars (sparp_t *sparp, dk_set_t parent_gps);
 
+/*! Visits all subtres and subqueries of \c tree and places all distinct names of global and external variables to \c set_set[0] */
+extern void sparp_list_external_vars (sparp_t *sparp, SPART *tree, dk_set_t *set_ret);
+
 /*! Removes equivalence classes that are no longer in any sort of use (neither pure connections nor equivs of actual variables */
 extern void sparp_remove_totally_useless_equivs (sparp_t *sparp);
 
@@ -629,7 +634,7 @@ extern void sparp_remove_redundant_connections (sparp_t *sparp, ptrlong flags);
 /*! Given an OPTIONAL_L right side of loj (specified by combination of \c parent and \c pos_of_curr_memb) and an equiv \c eq,
 this finds the most restrictive variable or retval at left side, and fills in \c ret_parent_eq[0] and \c ret_tree_in_parent[0].
 If \c eq->e_replaces_filter and eq is not assigned locally then a condition with ret_tree_in_parent[0] instead of \c eq will act as a filter.
-The repated expression can be placed in ON (...) clause of the generated LEFT OUTER JOIN and thus preserved from being lost due to lack of
+The repeated expression can be placed in ON (...) clause of the generated LEFT OUTER JOIN and thus preserved from being lost due to lack of
 appropriated variables in scope of WHERE clause of SELECT at the right size of loj. */
 extern void sparp_find_best_join_eq_for_optional (sparp_t *sparp, SPART *parent, int pos_of_curr_memb, sparp_equiv_t *eq, sparp_equiv_t **ret_parent_eq, SPART **ret_tree_in_parent);
 
@@ -746,7 +751,9 @@ typedef struct spar_sqlgen_s
   sparp_equiv_t		**ssg_equivs;		/*!< Shorthand for ssg_sparp->sparp_sg->sg_equivs */
   ptrlong		ssg_equiv_count;	/*!< Shorthand for ssg_sparp->sparp_sg->sg_equiv_count */
   struct spar_sqlgen_s  *ssg_parent_ssg;	/*!< Ssg that prints outer subquery */
-  SPART			*ssg_wrapping_gp;	/*!< Gp of subtype SELECT_L that contains the current subquery */
+  struct spar_sqlgen_s	*ssg_nested_ssg;	/*!< Ssg that prints some fragment for the current one, like a text of query to send to a remote service. This is used for GC on abort */
+  SPART *		ssg_wrapping_gp;	/*!< Gp of subtype SELECT_L or SERVICE_L that contains the current subquery */
+  SPART *		ssg_wrapping_sinv;	/*!< service invocation description of \c ssg_wrapping_p in case of SERVICE_L gp subtype */
 /* Run-time environment */
   SPART			**ssg_sources;		/*!< Data sources from ssg_tree->_.req_top.sources and/or environment */
 /* SQL Codegen temporary values */
@@ -768,8 +775,11 @@ typedef struct spar_sqlgen_s
   SPART *		ssg_sd_prev_pred;	/*!< Predicate of the previous triple in a group, to make a decision about using ',' shorthand */
   caddr_t		ssg_sd_single_from;	/*!< The IRI in FROM clause, if there's only one FROM clause, NULL otherwise */
   int			ssg_sd_graph_gp_nesting;	/*!< Count of GRAPH {...} gps that are opened but not yet closed */
+  dk_set_t		ssg_param_pos_set;	/*!< revlist of byte offsets of params in text and numbers of params in question, for sinv templates with unsupported named params */
 } spar_sqlgen_t;
 
+/*!< Releases non-mempooled internals of \c ssg (currently the ssg_out) but does not free \c ssg itself (it's supposed to be on stack (if top-level) or in mem pool (if top-level or nested) */
+void ssg_free_internals (spar_sqlgen_t *ssg);
 
 #define ssg_putchar(c) session_buffered_write_char (c, ssg->ssg_out)
 #define ssg_puts(strg) session_buffered_write (ssg->ssg_out, strg, strlen (strg))
@@ -786,7 +796,7 @@ extern void spar_sqlprint_error_impl (spar_sqlgen_t *ssg, const char *msg);
 #endif
 
 
-#define SSG_INDENT_FACTOR 4
+#define SSG_INDENT_FACTOR 2
 #define SSG_MAX_ALLOWED_LINE_COUNT 10000
 #define ssg_newline(back) \
   do { \
@@ -830,7 +840,8 @@ extern ssg_valmode_t sparp_rettype_of_function (sparp_t *sparp, caddr_t name);
 extern ssg_valmode_t sparp_argtype_of_function (sparp_t *sparp, caddr_t name, int arg_idx);
 extern void ssg_prin_function_name (spar_sqlgen_t *ssg, ccaddr_t name);
 
-extern void ssg_print_global_param (spar_sqlgen_t *ssg, caddr_t vname, ssg_valmode_t needed);
+extern void ssg_print_global_param (spar_sqlgen_t *ssg, SPART *var, ssg_valmode_t needed);
+extern void ssg_print_global_param_name (spar_sqlgen_t *ssg, caddr_t vname);
 extern void ssg_print_valmoded_scalar_expn (spar_sqlgen_t *ssg, SPART *tree, ssg_valmode_t needed, ssg_valmode_t native, const char *asname);
 extern void ssg_print_scalar_expn (spar_sqlgen_t *ssg, SPART *tree, ssg_valmode_t needed, const char *asname);
 extern void ssg_print_filter_expn (spar_sqlgen_t *ssg, SPART *tree);
@@ -859,9 +870,13 @@ extern void ssg_print_retval_simple_expn (spar_sqlgen_t *ssg, SPART *gp, SPART *
 extern void ssg_print_fld_var_restrictions_ex (spar_sqlgen_t *ssg, quad_map_t *qmap, qm_value_t *field, caddr_t tabid, SPART *fld_tree, SPART *triple, SPART *fld_if_outer, rdf_val_range_t *rvr);
 extern void ssg_print_fld_restrictions (spar_sqlgen_t *ssg, quad_map_t *qmap, qm_value_t *field, caddr_t tabid, SPART *triple, int fld_idx, int print_outer_filter);
 extern void ssg_print_all_table_fld_restrictions (spar_sqlgen_t *ssg, quad_map_t *qm, caddr_t alias, SPART *triple, int enabled_field_bitmask, int print_outer_filter);
-extern void ssg_print_table_exp (spar_sqlgen_t *ssg, SPART *gp, SPART **trees, int tree_count, int pass);
 
+#define	SSG_TABLE_SELECT_PASS		1
+#define	SSG_TABLE_WHERE_PASS		2
+#define	SSG_TABLE_PVIEW_PARAM_PASS	3
+extern void ssg_print_table_exp (spar_sqlgen_t *ssg, SPART *gp, SPART **trees, int tree_count, int pass);
 extern void ssg_print_subquery_table_exp (spar_sqlgen_t *ssg, SPART *wrapping_gp);
+extern void ssg_print_sinv_table_exp (spar_sqlgen_t *ssg, SPART *gp, int pass);
 extern void ssg_print_scalar_subquery_exp (spar_sqlgen_t *ssg, SPART *sub_req_top, SPART *wrapping_gp, ssg_valmode_t needed);
 
 #define SSG_PRINT_UNION_NOFIRSTHEAD	0x01	/*!< Flag to suppress printing of 'SELECT retvallist' of the first member of the union */
@@ -898,12 +913,15 @@ An occurrence of a non-blocking feature provides some hint to the optimizer of t
 #define SSG_SD_RVR		0x0010	/*!< Flags if RVR hint options should be printed, this has no effect w/o SSG_SD_OPTION */
 #define SSG_SD_IN		0x0020	/*!< Allows the use of IN operator, non-blocking because can be replaced with '=' */
 #define SSG_SD_LIKE		0x0040	/*!< Allows the use of LIKE operator, blocking */
-#define SSG_SD_BI		0x0080	/*!< Allows the use of SPARQL-BI extensions, blocking in most of cases */
-#define SSG_SD_VOS_509		0x00FF	/*!< Allows everything that is supported by Virtuoso Open Source 5.0.9 */
-#define SSG_SD_SERVICE		0x0100	/*!< Allows the use of SERVICE extension, blocking */
-#define SSG_SD_TRANSIT		0x0200	/*!< Allows the use of SERVICE extension, blocking */
-#define SSG_SD_VOS6		0x0FFF	/*!< Allows everything that is supported by Virtuoso Open Source 6.0.0 */
-#define SSG_SD_VOS_CURRENT	SSG_SD_VOS_509	/*!< Allows everything that is supported by current version of Virtuoso */
+#define SSG_SD_GLOBALS		0x0080	/*!< Allows the use of global variables (with colon at the front of the name), blocking in most of cases */
+#define SSG_SD_BI		0x0100	/*!< Allows the use of SPARQL-BI extensions, blocking in most of cases */
+#define SSG_SD_VIRTSPECIFIC	0x0200	/*!< Allows the use of Virtuoso-specific features not listed above, say DEFINE, blocking in most of cases */
+#define SSG_SD_VOS_509		0x03FF	/*!< Allows everything that is supported by Virtuoso Open Source 5.0.9 */
+#define SSG_SD_SERVICE		0x0400	/*!< Allows the use of SERVICE extension, blocking */
+#define SSG_SD_VOS_5_LATEST	0x0FFF	/*!< Allows everything that is supported by CVS had of Virtuoso Open Source 5.x.x */
+#define SSG_SD_TRANSIT		0x1000	/*!< Allows the use of transitivity extension, blocking */
+#define SSG_SD_VOS_6		0x1FFF	/*!< Allows everything that is supported by Virtuoso Open Source 6.0.0 */
+#define SSG_SD_VOS_CURRENT	SSG_SD_VOS_6	/*!< Allows everything that is supported by current version of Virtuoso */
 
 extern void ssg_sdprin_literal (spar_sqlgen_t *ssg, SPART *tree);
 extern void ssg_sdprin_qname (spar_sqlgen_t *ssg, SPART *tree);
