@@ -1,7 +1,7 @@
 /*
  *  sqlcost.c
  *
- *  $Id: sqlcost.c,v 1.30.2.19 2010/02/01 12:53:45 source Exp $
+ *  $Id: sqlcost.c,v 1.30.2.24 2010/04/06 14:43:57 source Exp $
  *
  *  sql cost functions
  *
@@ -869,7 +869,8 @@ sqlo_iri_constant_name_1 (ST* tree)
     return (caddr_t)tree;
   if (ST_P (tree, CALL_STMT) && 1 <= BOX_ELEMENTS (tree->_.call.params)
       && DV_STRINGP (tree->_.call.name)
-      && (0 == stricmp (tree->_.call.name, "__BFT") || 0 == stricmp (tree->_.call.name, "__box_flags_tweak")))
+      && (0 == stricmp (tree->_.call.name, "__BFT") || 0 == stricmp (tree->_.call.name, "__box_flags_tweak")
+	 || 0 == strnicmp (tree->_.call.name, "__I2ID", 6) || 0 == strnicmp (tree->_.call.name, "IRI_TO_ID", 9)))
     return (caddr_t) sqlo_iri_constant_name_1  (tree->_.call.params[0]);
   return NULL;
 }
@@ -883,7 +884,7 @@ sqlo_iri_constant_name (ST* tree)
     return (caddr_t)tree;
   if (ST_P (tree, CALL_STMT) && 1 <= BOX_ELEMENTS (tree->_.call.params)
       && DV_STRINGP (tree->_.call.name)
-      && 0 == strnicmp (tree->_.call.name, "__I2ID", 6)
+      && (0 == strnicmp (tree->_.call.name, "__I2ID", 6) || 0 == strnicmp (tree->_.call.name, "IRI_TO_ID", 9))
       && DV_STRINGP ((name = sqlo_iri_constant_name_1 (tree->_.call.params[0]))))
     return name;
   return NULL;
@@ -1622,7 +1623,7 @@ sqlo_inx_intersect_cost (df_elt_t * tb_dfe, dk_set_t col_preds, dk_set_t group,
       cf = cf + log (arity[nth_term]) * ROW_SKIP_COST * 0.1;
       dio->dio_table->_.table.key = prev_key;
       nth_term++;
-      if (nth_term > 10)
+      if (nth_term >= 10)
 	break;
     }
   END_DO_SET();
@@ -2082,11 +2083,11 @@ sqlo_proc_table_cost (df_elt_t * dt_dfe, float * u1, float * a1)
 
       DO_SET (df_elt_t *, colp_dfe, &dt_dfe->_.sub.dt_preds)
 	{
-	  if (ST_P (colp_dfe->dfe_tree->_.bin_exp.left, COL_DOTTED) &&
+	  if (ST_COLUMN (colp_dfe->dfe_tree->_.bin_exp.left, COL_DOTTED) &&
 	      (!CASEMODESTRCMP (name, colp_dfe->dfe_tree->_.bin_exp.left->_.col_ref.name)
 	       || box_equal (name, colp_dfe->dfe_tree->_.bin_exp.left->_.col_ref.name)))
 	    goto next_arg;
-	  else if (ST_P (colp_dfe->dfe_tree->_.bin_exp.right, COL_DOTTED) &&
+	  else if (ST_COLUMN (colp_dfe->dfe_tree->_.bin_exp.right, COL_DOTTED) &&
 		   (!CASEMODESTRCMP (name, colp_dfe->dfe_tree->_.bin_exp.right->_.col_ref.name)
 		    || box_equal (name, colp_dfe->dfe_tree->_.bin_exp.right->_.col_ref.name)))
 	    goto next_arg;
@@ -2094,11 +2095,11 @@ sqlo_proc_table_cost (df_elt_t * dt_dfe, float * u1, float * a1)
       END_DO_SET();
       DO_SET (df_elt_t *, colp_dfe, &dt_dfe->_.sub.dt_imp_preds)
 	{
-	  if (ST_P (colp_dfe->dfe_tree->_.bin_exp.left, COL_DOTTED) &&
+	  if (ST_COLUMN (colp_dfe->dfe_tree->_.bin_exp.left, COL_DOTTED) &&
 	      (!CASEMODESTRCMP (name, colp_dfe->dfe_tree->_.bin_exp.left->_.col_ref.name)
 	       || box_equal (name, colp_dfe->dfe_tree->_.bin_exp.left->_.col_ref.name)))
 	    goto next_arg;
-	  else if (ST_P (colp_dfe->dfe_tree->_.bin_exp.right, COL_DOTTED) &&
+	  else if (ST_COLUMN (colp_dfe->dfe_tree->_.bin_exp.right, COL_DOTTED) &&
 		   (!CASEMODESTRCMP (name, colp_dfe->dfe_tree->_.bin_exp.right->_.col_ref.name)
 		    || box_equal (name, colp_dfe->dfe_tree->_.bin_exp.right->_.col_ref.name)))
 	    goto next_arg;
@@ -2106,11 +2107,11 @@ sqlo_proc_table_cost (df_elt_t * dt_dfe, float * u1, float * a1)
       END_DO_SET();
       DO_SET (df_elt_t *, colp_dfe, &dt_dfe->_.sub.ot->ot_join_preds)
 	{
-	  if (ST_P (colp_dfe->dfe_tree->_.bin_exp.left, COL_DOTTED) &&
+	  if (ST_COLUMN (colp_dfe->dfe_tree->_.bin_exp.left, COL_DOTTED) &&
 	      (!CASEMODESTRCMP (name, colp_dfe->dfe_tree->_.bin_exp.left->_.col_ref.name)
 	       || box_equal (name, colp_dfe->dfe_tree->_.bin_exp.left->_.col_ref.name)))
 	    goto next_arg;
-	  else if (ST_P (colp_dfe->dfe_tree->_.bin_exp.right, COL_DOTTED) &&
+	  else if (ST_COLUMN (colp_dfe->dfe_tree->_.bin_exp.right, COL_DOTTED) &&
 		   (!CASEMODESTRCMP (name, colp_dfe->dfe_tree->_.bin_exp.right->_.col_ref.name)
 		    || box_equal (name, colp_dfe->dfe_tree->_.bin_exp.right->_.col_ref.name)))
 	    goto next_arg;
@@ -2286,7 +2287,7 @@ dfe_unit_cost (df_elt_t * dfe, float input_arity, float * u1, float * a1, float
 	  if (is_oby_order)
 	    *u1 = 0;
 	  else if (dfe->_.setp.top_cnt)
-	    /* with a top sort node, it is log2 of the top cnt and half the cost of the inx sprt temp.  Add 1 becauase log (1) is zero  */
+	    /* with a top sort node, it is log2 of the top cnt and half the cost of the inx sprt temp.  Add 1 because log (1) is zero  */
 	    *u1 = (float) 0.5 * (INX_ROW_INS_COST + INX_CMP_COST *  log ((double) dfe->_.setp.top_cnt + 1) / log (2));
 	  else
 	    *u1 = (float) INX_ROW_INS_COST + MAX (1, 1 + INX_CMP_COST * log (input_arity) / log (2));
