@@ -1,7 +1,7 @@
 /*
  *  sqlexp.c
  *
- *  $Id: sqlexp.c,v 1.16.2.17 2010/02/03 10:29:01 source Exp $
+ *  $Id: sqlexp.c,v 1.16.2.21 2010/04/26 14:41:41 source Exp $
  *
  *  Dynamic SQL Expression Generator
  *
@@ -170,8 +170,8 @@ sqlc_trans_funcs (sql_comp_t * sc, ST * tree, state_slot_t * ret)
       dtp = DV_TYPE_OF (arg);
       if (DV_LONG_INT == dtp)
 	{
-	  if (BOX_ELEMENTS (sc->sc_trans->tn_input) < unbox ((caddr_t)arg) - 1 || unbox (arg) < 1)
-	    sqlc_new_error (sc->sc_cc, "37000", "TR...", "t_step  argument not an index  to a column in the selection");
+	  if (BOX_ELEMENTS (sc->sc_trans->tn_input) <= unbox ((caddr_t)arg) - 1 || unbox (arg) < 1)
+	    sqlc_new_error (sc->sc_cc, "37000", "TR...", "t_step argument not an index to a column in the selection");
 	  if (!sc->sc_trans->tn_step_out)
 	    {
 	      sc->sc_trans->tn_step_out = (state_slot_t **)box_copy ((caddr_t)sc->sc_trans->tn_input);
@@ -428,7 +428,7 @@ sqlg_unplace_ssl (sqlo_t * so, ST * tree)
   int inx;
   if (DV_ARRAY_OF_POINTER != DV_TYPE_OF (tree))
     return;
-  if (ST_P(tree, COL_DOTTED))
+  if (ST_COLUMN(tree, COL_DOTTED))
     return;
   dfe = sqlo_df_elt (so, tree);
   if (dfe && dfe->dfe_ssl)
@@ -681,7 +681,7 @@ scalar_exp_generate (sql_comp_t * sc, ST * tree, dk_set_t * code)
     {
       seg_return (ssl_new_constant (sc->sc_cc, (caddr_t) tree->_.op.arg_1));
     }
-  if (ST_P (tree, COL_DOTTED) ||
+  if (ST_COLUMN (tree, COL_DOTTED) ||
       ST_P (tree, FUN_REF))
     {
       state_slot_t * ssl;
@@ -712,7 +712,10 @@ scalar_exp_generate (sql_comp_t * sc, ST * tree, dk_set_t * code)
       ins->_.artm.right = right;
       ins->_.artm.result = sqlc_new_temp (sc, "temp", DV_UNKNOWN);
       if (ins->ins_type == INS_NOT_VALID)
-	sqlc_new_error (sc->sc_cc, "37000", "SQ460", "Invalid arithmetic operation");
+	{
+	  t_set_pop (code);
+	  sqlc_new_error (sc->sc_cc, "37000", "SQ460", "Invalid arithmetic operation");
+	}
       cv_artm_set_type (ins);
       seg_return (ins->_.artm.result);
     }
@@ -1892,7 +1895,7 @@ qn_refd_slots (sql_comp_t * sc, data_source_t * qn, dk_hash_t * res, dk_hash_t *
   int inx;
   cv_refd_slots (sc, qn->src_after_code, res, all_res, non_cl_local);
   cv_refd_slots (sc, qn->src_after_test, res, all_res, non_cl_local);
-  if (IS_TS ((table_source_t*) qn))
+  if (IS_TS ((table_source_t*) qn) || IS_QN (qn, sort_read_input))
     {
       table_source_t * ts = (table_source_t *) qn;
       cv_refd_slots (sc, ts->ts_after_join_test, res, all_res, non_cl_local);
