@@ -1,7 +1,7 @@
 /*
  *  trans.c
  *
- *  $Id: trans.c,v 1.1.2.4 2009/09/27 22:03:57 source Exp $
+ *  $Id: trans.c,v 1.1.2.7 2010/06/30 14:29:58 source Exp $
  *
  *  Transitive Node
  *
@@ -205,6 +205,11 @@ tn_read_lc (trans_node_t * tn, caddr_t * inst, srv_stmt_t * lc, caddr_t * arr, c
 	  int set_no = lc_set_no (lc);
 	  dk_set_t * place = (dk_set_t*) id_hash_get (relation, (caddr_t)&arr[set_no]);
 	  any[set_no] = 1;
+	  if (THR_TMP_POOL->mp_bytes > tn->tn_max_memory)
+	    {
+	      SET_THR_TMP_POOL (NULL);
+	      sqlr_new_error ("42000", "TN...", "Exceeded " BOXINT_FMT " bytes in transitive temp memory.  This was detected in expanding a owl:sameAs or IFP implied identity.", (boxint) tn->tn_max_memory);
+	    }
 	  if (place)
 	    t_set_push (place, (void*) lc_t_row (lc));
 	  else
@@ -348,6 +353,11 @@ tn_read_inlined (trans_node_t * tn, caddr_t * inst, caddr_t * arr, caddr_t any,
 	  int set_no = subq_set_no (tn->tn_inlined_step, inst);
 	  dk_set_t * place = (dk_set_t*) id_hash_get (relation, (caddr_t)&arr[set_no]);
 	  any[set_no] = 1;
+	  if (THR_TMP_POOL->mp_bytes > tn->tn_max_memory)
+	    {
+	      SET_THR_TMP_POOL (NULL);
+	      sqlr_new_error ("42000", "TN...", "Exceeded " BOXINT_FMT " bytes in transitive temp memory.  use t_distinct, t_max or more T_MAX_memory options to limit the search or increase the pool", (boxint) tn->tn_max_memory);
+	    }
 	  if (place)
 	    t_set_push (place, (void*) tn_t_row (tn, inst));
 	  else
@@ -1230,8 +1240,9 @@ tn_free (trans_node_t * tn)
   dk_free_tree ((caddr_t)tn->tn_output_pos);
   dk_free_box ((caddr_t)tn->tn_data);
   dk_free_box ((caddr_t)tn->tn_target);
-
   dk_free_box ((caddr_t)tn->tn_sas_g);
+  dk_free_box ((caddr_t)tn->tn_step_out);
+  cv_free (tn->tn_after_join_test);
   dk_free_box (tn->tn_ifp_ctx_name);
 }
 
@@ -1431,7 +1442,7 @@ sqlg_distinct_same_as_1 (sqlo_t * so, data_source_t ** q_head,
 	  tn->tn_sas_g = gs;
 	}
       else
-	tn->tn_sas_g = (state_slot_t **) list (1, g_dfe->_.bin.right->dfe_ssl);
+	tn->tn_sas_g = (state_slot_t **) list (1, g_dfe->_.bin.right->dfe_ssl ? g_dfe->_.bin.right->dfe_ssl : g_dfe->_.bin.left->dfe_ssl);
       tn->tn_lowest_sas = 1;
       tn->tn_distinct = 1;
       tn->tn_commutative = 1;
