@@ -1,5 +1,5 @@
 --
---  $Id: url_rewrite.sql,v 1.34.2.4 2011/06/24 11:16:59 source Exp $
+--  $Id: url_rewrite.sql,v 1.26.2.11 2010/06/18 11:08:14 source Exp $
 --
 --  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 --  project.
@@ -428,8 +428,10 @@ end_scan:
       long_path := replace (long_path, '^{URIQADefaultHost}^', host);
       if (strstr (long_path, '^{DynamicLocalFormat}^') is not null)
         {
-	  long_path := replace (long_path, '^{DynamicLocalFormat}^',
-	  	sprintf ('%s://%{WSHost}s', case when is_https_ctx () then 'https' else 'http' end));
+          if (strchr (host, ':') is not null)
+            long_path := replace (long_path, '^{DynamicLocalFormat}^', sprintf ('http://%{WSHostName}U:%{WSHostPort}U'));
+          else
+            long_path := replace (long_path, '^{DynamicLocalFormat}^', sprintf ('http://%{WSHost}U'));
         }
     }
   return long_path;
@@ -452,9 +454,7 @@ create procedure DB.DBA.URLREWRITE_APPLY_RECURSIVE (
   out target_vhost_pkey any,
   out http_redir int,
   out http_headers varchar,
-  inout lines any,
-  in meth varchar
-  )
+  inout lines any)
   returns integer
 {
 -- dbg_obj_princ('in side! ', rulelist_iri);
@@ -464,7 +464,7 @@ create procedure DB.DBA.URLREWRITE_APPLY_RECURSIVE (
         {
           if (DB.DBA.URLREWRITE_APPLY_RECURSIVE (cur_iri, nice_host,
             nice_lhost, nice_lpath, nice_get_params, nice_frag, post_params, accept_header, long_url, params,
-            rule_iri, target_vhost_pkey, http_redir, http_headers, lines, meth) = 1)
+            rule_iri, target_vhost_pkey, http_redir, http_headers, lines) = 1)
             return 1;
         }
       else
@@ -489,13 +489,6 @@ create procedure DB.DBA.URLREWRITE_APPLY_RECURSIVE (
 	          if (accept_val is null)
 		    goto next_rule;
 		}
-	      -- cannot do redirect on POST or PUT or something having a content sent as part of the request
-	      if (URR_HTTP_REDIRECT is not null and URR_HTTP_REDIRECT > 299 and URR_HTTP_REDIRECT < 304 and meth not in ('GET', 'MGET', 'HEAD'))
-		{
-		  if (registry_get ('__debug_url_rewrite') in ('1', '2'))
-		    dbg_printf ('skipping rule=[%s] because HTTP redirect cannot be done for HTTP %s', URR_NICE_FORMAT, meth);
-		  goto next_rule;
-		}
 
               if (URR_RULE_TYPE = 0)
                 {
@@ -643,8 +636,7 @@ create procedure DB.DBA.URLREWRITE_APPLY (
     target_vhost_pkey,
     http_redir,
     http_headers,
-    lines,
-    'GET');
+    lines);
 }
 ;
 
@@ -1009,7 +1001,10 @@ create procedure DB.DBA.HTTP_URLREWRITE_APPLY_PATTERN (in pattern varchar, in st
       ret := replace (ret, '^{URIQADefaultHost}^', host);
       if (strstr (ret, '^{DynamicLocalFormat}^') is not null)
         {
-	  ret := replace (ret, '^{DynamicLocalFormat}^', sprintf ('%s://%{WSHost}s', case when is_https_ctx () then 'https' else 'http' end));
+          if (strchr (host, ':') is not null)
+            ret := replace (ret, '^{DynamicLocalFormat}^', sprintf ('http://%{WSHostName}U:%{WSHostPort}U'));
+          else
+            ret := replace (ret, '^{DynamicLocalFormat}^', sprintf ('http://%{WSHost}U'));
         }
     }
    return ret;
@@ -1207,7 +1202,7 @@ create procedure DB.DBA.HTTP_URLREWRITE (in path varchar, in rule_list varchar,
   declare params, lines any;
   declare nice_vhost_pkey any;
   declare top_rulelist_iri varchar;
-  declare rule_iri, in_path, qstr, meth varchar;
+  declare rule_iri, in_path, qstr varchar;
   declare target_vhost_pkey, hf, accept, http_headers any;
   declare result, http_redir, http_tcn_code, tcn_rc, keep_lpath int;
   declare http_tcn_headers varchar;
@@ -1221,7 +1216,6 @@ create procedure DB.DBA.HTTP_URLREWRITE (in path varchar, in rule_list varchar,
   accept := null;
   qstr := null;
   keep_lpath := 0;
-  meth := 'GET';
 
   if (is_http_ctx ())
     {
@@ -1238,7 +1232,6 @@ create procedure DB.DBA.HTTP_URLREWRITE (in path varchar, in rule_list varchar,
       accept := http_request_header (lines, 'Accept');
       if (not isstring (accept))
 	accept := '*/*';
-      meth := http_request_get ('REQUEST_METHOD');
     }
   else
     {
@@ -1248,15 +1241,12 @@ create procedure DB.DBA.HTTP_URLREWRITE (in path varchar, in rule_list varchar,
   if (length (qstr))
     in_path := in_path || '?' || qstr;
 
-  if (registry_get ('__debug_url_rewrite') in ('1', '2'))
-    dbg_printf ('Input URL=[%s]', in_path);
-
   http_tcn_headers := http_headers := null;
   http_tcn_code := http_redir := null;
   tcn_rc := DB.DBA.URLREWRITE_APPLY_TCN (rule_list, in_path, lines, http_tcn_code, http_tcn_headers);
 --  dbg_obj_print ('http headers', http_tcn_code, http_tcn_headers);
   result := DB.DBA.URLREWRITE_APPLY_RECURSIVE (rule_list, null, null, in_path, '', qstr, post_params, accept,
-  	long_url, params, rule_iri, target_vhost_pkey, http_redir, http_headers, lines, meth);
+  	long_url, params, rule_iri, target_vhost_pkey, http_redir, http_headers, lines);
   if (registry_get ('__debug_url_rewrite') in ('1', '2') and length (long_url))
     dbg_printf ('*** RETURN rule=[%s] URL=[%s]', rule_iri, long_url);
   if (not tcn_rc and length (long_url))
@@ -1298,11 +1288,6 @@ create procedure DB.DBA.HTTP_URLREWRITE (in path varchar, in rule_list varchar,
               http_headers := replace (http_headers, tmp, repl);
               tmp := regexp_match ('\\^{sql:[^}]*}\\^', http_headers);
 	    }
-	  if (strstr (http_headers, '^{DynamicLocalFormat}^') is not null)
-	    {
-	      http_headers := replace (http_headers, '^{DynamicLocalFormat}^',
-	         sprintf ('%s://%{WSHost}s', case when is_https_ctx () then 'https' else 'http' end));
-	    }
 
 	  http_headers := rtrim (http_headers, '\r\n');
 	  if (length (http_headers))
@@ -1317,21 +1302,18 @@ create procedure DB.DBA.HTTP_URLREWRITE (in path varchar, in rule_list varchar,
 	  http_status_set (http_redir);
 	  http_header (http_header_get () || 'Location: '|| DB.DBA.HTTP_LOC_NEW_URL (long_url) ||'\r\n');
 	  http_body_read ();
-	  if (registry_get ('__debug_url_rewrite') in ('1', '2')) dbg_printf ('HTTP redirect');
 	  return 1;
 	}
       else if (http_redir = 300) -- TCN
         {
 	  http_status_set (http_redir);
 	  http_body_read ();
-	  if (registry_get ('__debug_url_rewrite') in ('1', '2')) dbg_printf ('HTTP redirect');
 	  return 1;
         }
       else if (isinteger (http_redir) and http_redir > 399)
 	{
 	  http_status_set (http_redir);
 	  http_body_read ();
-	  if (registry_get ('__debug_url_rewrite') in ('1', '2')) dbg_printf ('HTTP status');
 	  return 1;
 	}
       else
@@ -1343,7 +1325,6 @@ create procedure DB.DBA.HTTP_URLREWRITE (in path varchar, in rule_list varchar,
 	  http_internal_redirect (full_path, p_full_path, long_url, keep_lpath);
 	  pars := vector_concat (params, pars);
 	  http_set_params (pars);
-	  if (registry_get ('__debug_url_rewrite') in ('1', '2')) dbg_printf ('Internal redirect');
         }
     }
   return 0;
@@ -1419,3 +1400,16 @@ create procedure DB.DBA.URLREWRITE_DUMP_RULELIST_SQL (in rulelist_iri varchar)
   return string_output_string (ses);
 }
 ;
+
+--#IF VER=5
+--!AFTER
+--#ENDIF
+virt_proxy_init ()
+;
+
+--#IF VER=5
+--!AFTER
+--#ENDIF
+grant execute on ext_http_proxy to PROXY
+;
+
