@@ -1,7 +1,7 @@
 /*
  *  widisk.h
  *
- *  $Id: widisk.h,v 1.12.2.7 2010/02/01 23:14:46 source Exp $
+ *  $Id: widisk.h,v 1.12.2.8 2010/02/24 13:02:42 source Exp $
  *
  *  Disk Based Data Structures
  *
@@ -251,8 +251,8 @@ typedef unsigned char * db_buf_t;
 #define INT64_REF(p) \
     ( \
       (  ((int64)((short*)(p))[0]) << 48) \
-      | (((int64)((unsigned short*)(p))[1]) << 32) \
-      | (((int32)((unsigned short*)(p))[2]) << 16) \
+      | (((unsigned int64)((unsigned short*)(p))[1]) << 32) \
+      | (((uint32)((unsigned short*)(p))[2]) << 16) \
       | (((unsigned short*)(p))[3]) \
     )
 
